@@ -1,24 +1,24 @@
-//////////////////////////////////////////////////////////////////////////////
-//
-//    RESIZEIMAGESDIALOG.CPP
-//
-//    Copyright (C) 2004 Gilles CAULIER <caulier dot gilles at gmail dot com>
-//
-//    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
-//    (at your option) any later version.
-//
-//    This program is distributed in the hope that it will be useful,
-//    but WITHOUT ANY WARRANTY; without even the implied warranty of
-//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//    GNU General Public License for more details.
-//
-//    You should have received a copy of the GNU General Public License
-//    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
-//
-//////////////////////////////////////////////////////////////////////////////
+/* ============================================================
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-10-01
+ * Description : a kipi plugin to batch process images
+ *
+ * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * This program is free software; you can redistribute it
+ * and/or modify it under the terms of the GNU General
+ * Public License as published by the Free Software Foundation;
+ * either version 2, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * ============================================================ */
 
 // Include files for Qt
 
@@ -55,27 +55,25 @@
 namespace KIPIBatchProcessImagesPlugin
 {
 
-//////////////////////////////////// CONSTRUCTOR ////////////////////////////////////////////
-
 ResizeImagesDialog::ResizeImagesDialog( KURL::List urlList, KIPI::Interface* interface, QWidget *parent )
-                 : BatchProcessImagesDialog( urlList, interface, i18n("Batch Resize Images"), parent )
+                  : BatchProcessImagesDialog( urlList, interface, i18n("Batch Resize Images"), parent )
 {
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Batch resize images"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to batch-resize images\n"
                                                      "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
-                                           "(c) 2003-2004, Gilles Caulier");
+                                           "(c) 2003-2007, Gilles Caulier");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at gmail dot com");
+                       "caulier dot gilles at gmail dot com");
 
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Batch Resize Images Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     //---------------------------------------------
@@ -119,26 +117,16 @@ ResizeImagesDialog::ResizeImagesDialog( KURL::List urlList, KIPI::Interface* int
     listImageFiles();
 }
 
-
-//////////////////////////////////// DESTRUCTOR /////////////////////////////////////////////
-
 ResizeImagesDialog::~ResizeImagesDialog()
 {
     delete m_about;
 }
 
-
-//////////////////////////////////////// SLOTS //////////////////////////////////////////////
-
 void ResizeImagesDialog::slotHelp( void )
 {
-    KApplication::kApplication()->invokeHelp("resizeimages",
-                                             "kipi-plugins");
+    KApplication::kApplication()->invokeHelp("resizeimages", "kipi-plugins");
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void ResizeImagesDialog::slotOptionsClicked(void)
 {
     int Type = m_Type->currentItem();
@@ -222,9 +210,6 @@ void ResizeImagesDialog::slotOptionsClicked(void)
     delete optionsDialog;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void ResizeImagesDialog::readSettings(void)
 {
     // Read all settings from configuration file.
@@ -273,9 +258,6 @@ void ResizeImagesDialog::readSettings(void)
     delete m_config;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 void ResizeImagesDialog::saveSettings(void)
 {
     // Write all settings in configuration file.
@@ -312,9 +294,6 @@ void ResizeImagesDialog::saveSettings(void)
     delete m_config;
 }
 
-
-////////////////////////////////////////////// FONCTIONS ////////////////////////////////////////////
-
 QString ResizeImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesItem *item,
                                         const QString& albumDest, bool )
 {
@@ -548,9 +527,6 @@ QString ResizeImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesItem *
     return(extractArguments(proc));
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 bool ResizeImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
                                              const QString& /*albumDest*/)
 {
@@ -566,9 +542,6 @@ bool ResizeImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
     return true;
 }
 
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-
 bool ResizeImagesDialog::ResizeImage( int &w, int &h, int SizeFactor)
 {
     bool valRet;
@@ -600,4 +573,3 @@ bool ResizeImagesDialog::ResizeImage( int &w, int &h, int SizeFactor)
 }
 
 }  // NameSpace KIPIBatchProcessImagesPlugin
-
