@@ -86,7 +86,7 @@ KIO::filesize_t TargetMediaSize;
 
 CDArchivingDialog::CDArchivingDialog( KIPI::Interface* interface, QWidget *parent)
                  : KDialogBase( IconList, i18n("Configure Archive to CD"), Help|Ok|Cancel, Ok,
-                                parent, "CDArchivingDialog", true, true ), m_interface( interface )
+                                parent, "CDArchivingDialog", true, false ), m_interface( interface )
 {
     setCaption(i18n("Create CD/DVD Archive"));
     setupSelection();
@@ -99,7 +99,7 @@ CDArchivingDialog::CDArchivingDialog( KIPI::Interface* interface, QWidget *paren
     // About data and help button.
     
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("CD/DVD Archiving"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("An Album CD/DVD Archiving Kipi plugin.\n"
                                                      "This plugin use K3b CD/DVD burning software available at\n"
@@ -121,7 +121,7 @@ CDArchivingDialog::CDArchivingDialog( KIPI::Interface* interface, QWidget *paren
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("CD/DVD Archiving Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 }
 
