@@ -2,7 +2,7 @@
  * File  : gallerywindow.h
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2004-11-30
- * Copyright 2004 by Renchi Raju
+ * Copyright 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -66,6 +66,8 @@ private:
     QPushButton              *m_newAlbumBtn;
     QPushButton              *m_addPhotoBtn;
     QPushButton              *m_helpButton;
+    QCheckBox                *m_captTitleCheckBox;
+    QCheckBox                *m_captDescrCheckBox;
     QCheckBox                *m_resizeCheckBox;
     QSpinBox                 *m_dimensionSpinBox;
     GalleryTalker            *m_talker;
