@@ -1,21 +1,23 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2006-09-19
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-09-19
  * Description : GPS file list view item.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- * 
+ * either version 2, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // Qt includes.
@@ -26,7 +28,6 @@
 // KDE includes.
 
 #include <klocale.h>
-#include <kio/previewjob.h>
 #include <kiconloader.h>
 
 // LibKExiv2 includes. 
@@ -36,7 +37,6 @@
 // Local includes.
 
 #include "gpslistviewitem.h"
-#include "gpslistviewitem.moc"
 
 namespace KIPIGPSSyncPlugin
 {
@@ -64,11 +64,11 @@ public:
 
     KURL             url;
 
-    GPSDataContainer gpsData;    
+    GPSDataContainer gpsData;
 };
 
 GPSListViewItem::GPSListViewItem(KListView *view, QListViewItem *after, const KURL& url)
-               : QObject(view), KListViewItem(view, after)
+               : KListViewItem(view, after)
 {
     d = new GPSListViewItemPriv;
     d->url = url;
@@ -76,7 +76,7 @@ GPSListViewItem::GPSListViewItem(KListView *view, QListViewItem *after, const KU
     setEnabled(false);
     setPixmap(0, SmallIcon( "file_broken", KIcon::SizeLarge, KIcon::DisabledState ));
     setText(1, d->url.fileName());
-    
+
     // We only add all JPEG files as R/W because Exiv2 can't yet 
     // update metadata on others file formats.
 
@@ -95,11 +95,6 @@ GPSListViewItem::GPSListViewItem(KListView *view, QListViewItem *after, const KU
     d->hasGPSInfo = exiv2Iface.getGPSInfo(alt, lat, lng);
     if (hasGPSInfo())
         setGPSInfo(GPSDataContainer(alt, lat, lng, false), false);
-
-    KIO::PreviewJob* thumbnailJob = KIO::filePreview(url, 64);
-
-    connect(thumbnailJob, SIGNAL(gotPreview(const KFileItem*, const QPixmap&)),
-            this, SLOT(slotGotThumbnail(const KFileItem*, const QPixmap&)));
 }
 
 GPSListViewItem::~GPSListViewItem()
@@ -107,7 +102,7 @@ GPSListViewItem::~GPSListViewItem()
     delete d;
 }
 
-void GPSListViewItem::setGPSInfo(GPSDataContainer gpsData, bool dirty, bool addedManually)
+void GPSListViewItem::setGPSInfo(const GPSDataContainer& gpsData, bool dirty, bool addedManually)
 {
     setEnabled(true);
     d->dirty      = dirty;
@@ -117,7 +112,7 @@ void GPSListViewItem::setGPSInfo(GPSDataContainer gpsData, bool dirty, bool adde
     setText(3, QString::number(d->gpsData.latitude(),  'g', 12));
     setText(4, QString::number(d->gpsData.longitude(), 'g', 12));
     setText(5, QString::number(d->gpsData.altitude(),  'g', 12));
-    
+
     if (isDirty())
     {
         QString status;
@@ -131,14 +126,14 @@ void GPSListViewItem::setGPSInfo(GPSDataContainer gpsData, bool dirty, bool adde
             else
                 status = i18n("Found");
         }
-        
+
         setText(6, status);
     }
-    
+
     repaint();
 }
 
-GPSDataContainer GPSListViewItem::getGPSInfo()
+GPSDataContainer GPSListViewItem::GPSInfo() const
 {
     return d->gpsData;
 }
@@ -154,7 +149,7 @@ void GPSListViewItem::eraseGPSInfo()
     }
 }
 
-void GPSListViewItem::setDateTime(QDateTime date)
+void GPSListViewItem::setDateTime(const QDateTime& date)
 {
     if (date.isValid())
     {
@@ -167,12 +162,12 @@ void GPSListViewItem::setDateTime(QDateTime date)
     }
 }
 
-QDateTime GPSListViewItem::getDateTime()
+QDateTime GPSListViewItem::dateTime() const
 {
     return d->date;
 }
 
-KURL GPSListViewItem::getUrl()
+KURL GPSListViewItem::url()
 {
     return d->url;
 }
@@ -205,13 +200,13 @@ void GPSListViewItem::writeGPSInfoToFile()
         }
 
         ret &= exiv2Iface.save(d->url.path());
-        
+
         if (ret)
             setPixmap(1, SmallIcon("ok"));
         else
             setPixmap(1, SmallIcon("cancel"));
-	
-	    d->dirty = false;
+
+        d->dirty = false;
     }
 }
 
@@ -269,11 +264,4 @@ void GPSListViewItem::paintCell(QPainter *p, const QColorGroup &cg, int column,
     }
 }
 
-void GPSListViewItem::slotGotThumbnail(const KFileItem*, const QPixmap& pix)
-{
-    setPixmap(0, pix);
-    repaint();
-}
-
 } // NameSpace KIPIGPSSyncPlugin
-
