@@ -1,20 +1,22 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2006-05-16
- * Description : a plugin to synchronize pictures with 
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-05-16
+ * Description : a plugin to synchronize pictures with
  *               a GPS device.
  *
- * Copyright 2006-2007 by Gilles Caulier
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -47,6 +49,7 @@
 #include <kglobalsettings.h>
 #include <knuminput.h>
 #include <kseparator.h>
+#include <kio/previewjob.h>
 
 // Local includes.
 
@@ -76,11 +79,10 @@ public:
         interpolateBox = 0;
         maxTimeInput   = 0;
         maxTimeLabel   = 0;
-
-        about = 0;
+        about          = 0;
     }
 
-    QLabel                         *gpxPointsLabel;
+    QLabel                   *gpxPointsLabel;
     QLabel                   *maxTimeLabel;
 
     QComboBox                *timeZoneCB;
@@ -96,15 +98,15 @@ public:
 
     KIPI::Interface          *interface;
 
-    KIPIPlugins::KPAboutData *about; 
+    KIPIPlugins::KPAboutData *about;
 
     GPSDataParser             gpxParser;
 };
 
 GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, QWidget* parent)
-             : KDialogBase(Plain, i18n("Geolocalization"), 
-                           Help|User1|User2|User3|Apply|Close, Close, 
-                           parent, 0, true, true )
+             : KDialogBase(Plain, i18n("Geolocation"),
+                           Help|User1|User2|User3|Apply|Close, Close,
+                           parent, 0, true, false)
 {
     d = new GPSSyncDialogPriv;
     d->interface = interface;
@@ -113,9 +115,9 @@ GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, QWidget* parent)
     setButtonText(User2, i18n("Edit..."));
     setButtonText(User3, i18n("Remove"));
 
-    setButtonTip(User1, i18n("Correlate GPX file data with all pictures from the list."));
-    setButtonTip(User2, i18n("Edit manually GPS coordinates of selected pictures from the list."));
-    setButtonTip(User3, i18n("Remove GPS coordinates of selected pictures from the list."));
+    setButtonTip(User1, i18n("Correlate in time and interpolate distance of data from GPX file with all images on the list."));
+    setButtonTip(User2, i18n("Manually edit GPS coordinates of selected images from the list."));
+    setButtonTip(User3, i18n("Remove GPS coordinates of selected images from the list."));
 
     enableButton(User1, false);
     enableButton(User2, true);
@@ -123,35 +125,12 @@ GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, QWidget* parent)
 
     QGridLayout *mainLayout = new QGridLayout(plainPage(), 3, 1, 0, marginHint());
 
-    //---------------------------------------------
-
-    QFrame *headerFrame = new QFrame( plainPage() );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Pictures Geolocalization"),
-                                     headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
     // --------------------------------------------------------------
 
     d->listView = new KListView(plainPage());
     d->listView->addColumn( i18n("Thumbnail") );
     d->listView->addColumn( i18n("File Name") );
-    d->listView->addColumn( i18n("Date Taken") );
+    d->listView->addColumn( i18n("Camera time stamp") );
     d->listView->addColumn( i18n("Latitude") );
     d->listView->addColumn( i18n("Longitude") );
     d->listView->addColumn( i18n("Altitude") );
@@ -176,87 +155,108 @@ GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, QWidget* parent)
     d->gpxPointsLabel    = new QLabel(settingsBox);
     KSeparator *line     = new KSeparator(Horizontal, settingsBox);
 
-    QLabel *maxGapLabel = new QLabel(i18n("Max gap time:"), settingsBox);
-    d->maxGapInput      = new KIntSpinBox(0, 2000, 1, 30, 10, settingsBox);
-    QWhatsThis::add(d->maxGapInput, i18n("<p>Set here the maximum distance in "
-                    "seconds from a GPS point that a photo will be matched."));
+    QLabel *maxGapLabel = new QLabel(i18n("Max. time gap (sec.):"), settingsBox);
+    d->maxGapInput      = new KIntSpinBox(0, 1000000, 1, 30, 10, settingsBox);
+    QWhatsThis::add(d->maxGapInput, i18n("<p>Sets the maximum difference in "
+                    "seconds from a GPS track point to the image time to be matched. "
+                    "If the time difference exceeds this setting, no match will be attempted."));
 
     QLabel *timeZoneLabel = new QLabel(i18n("Time zone:"), settingsBox);
     d->timeZoneCB         = new QComboBox( false, settingsBox );
-    d->timeZoneCB->insertItem(i18n("GMT-12:00"), 0);
-    d->timeZoneCB->insertItem(i18n("GMT-11:00"), 1);
-    d->timeZoneCB->insertItem(i18n("GMT-10:00"), 2);
-    d->timeZoneCB->insertItem(i18n("GMT-09:00"), 3);
-    d->timeZoneCB->insertItem(i18n("GMT-08:00"), 4);
-    d->timeZoneCB->insertItem(i18n("GMT-07:00"), 5);
-    d->timeZoneCB->insertItem(i18n("GMT-06:00"), 6);
-    d->timeZoneCB->insertItem(i18n("GMT-05:00"), 7);
-    d->timeZoneCB->insertItem(i18n("GMT-04:00"), 8);
-    d->timeZoneCB->insertItem(i18n("GMT-03:00"), 9);
-    d->timeZoneCB->insertItem(i18n("GMT-02:00"), 10);
-    d->timeZoneCB->insertItem(i18n("GMT-01:00"), 11);
-    d->timeZoneCB->insertItem(i18n("GMT"),       12);
-    d->timeZoneCB->insertItem(i18n("GMT+01:00"), 13);
-    d->timeZoneCB->insertItem(i18n("GMT+02:00"), 14);
-    d->timeZoneCB->insertItem(i18n("GMT+03:00"), 15);
-    d->timeZoneCB->insertItem(i18n("GMT+04:00"), 16);
-    d->timeZoneCB->insertItem(i18n("GMT+05:00"), 17);
-    d->timeZoneCB->insertItem(i18n("GMT+06:00"), 18);
-    d->timeZoneCB->insertItem(i18n("GMT+07:00"), 19);
-    d->timeZoneCB->insertItem(i18n("GMT+08:00"), 20);
-    d->timeZoneCB->insertItem(i18n("GMT+09:00"), 21);
-    d->timeZoneCB->insertItem(i18n("GMT+10:00"), 22);
-    d->timeZoneCB->insertItem(i18n("GMT+11:00"), 23);
-    d->timeZoneCB->insertItem(i18n("GMT+12:00"), 24);
-    QWhatsThis::add(d->timeZoneCB, i18n("<p>Set here the time zone where the "
-                    "pictures were taken in, so that the times of the pictures "
-                    "can be adjusted to match the GPS data"));
+
+    // See list of time zomes over the world :
+    // http://en.wikipedia.org/wiki/List_of_time_zones
+    // NOTE: Combo box strings are not i18n.
+    d->timeZoneCB->insertItem("GMT-12:00");
+    d->timeZoneCB->insertItem("GMT-11:00");
+    d->timeZoneCB->insertItem("GMT-10:00");
+    d->timeZoneCB->insertItem("GMT-09:30");
+    d->timeZoneCB->insertItem("GMT-09:00");
+    d->timeZoneCB->insertItem("GMT-08:00");
+    d->timeZoneCB->insertItem("GMT-07:00");
+    d->timeZoneCB->insertItem("GMT-06:00");
+    d->timeZoneCB->insertItem("GMT-05:30");
+    d->timeZoneCB->insertItem("GMT-05:00");
+    d->timeZoneCB->insertItem("GMT-04:30");
+    d->timeZoneCB->insertItem("GMT-04:00");
+    d->timeZoneCB->insertItem("GMT-03:30");
+    d->timeZoneCB->insertItem("GMT-03:00");
+    d->timeZoneCB->insertItem("GMT-02:00");
+    d->timeZoneCB->insertItem("GMT-01:00");
+    d->timeZoneCB->insertItem("GMT+00:00");
+    d->timeZoneCB->insertItem("GMT+01:00");
+    d->timeZoneCB->insertItem("GMT+02:00");
+    d->timeZoneCB->insertItem("GMT+03:00");
+    d->timeZoneCB->insertItem("GMT+03:30");
+    d->timeZoneCB->insertItem("GMT+04:00");
+    d->timeZoneCB->insertItem("GMT+05:00");
+    d->timeZoneCB->insertItem("GMT+05:30");    // See B.K.O # 149491
+    d->timeZoneCB->insertItem("GMT+05:45");
+    d->timeZoneCB->insertItem("GMT+06:00");
+    d->timeZoneCB->insertItem("GMT+06:30");
+    d->timeZoneCB->insertItem("GMT+07:00");
+    d->timeZoneCB->insertItem("GMT+08:00");
+    d->timeZoneCB->insertItem("GMT+08:45");
+    d->timeZoneCB->insertItem("GMT+09:00");
+    d->timeZoneCB->insertItem("GMT+09:30");
+    d->timeZoneCB->insertItem("GMT+10:00");
+    d->timeZoneCB->insertItem("GMT+10:30");
+    d->timeZoneCB->insertItem("GMT+11:00");
+    d->timeZoneCB->insertItem("GMT+11:30");
+    d->timeZoneCB->insertItem("GMT+12:00");
+    d->timeZoneCB->insertItem("GMT+12:45");
+    d->timeZoneCB->insertItem("GMT+13:00");
+    d->timeZoneCB->insertItem("GMT+14:00");
+    QWhatsThis::add(d->timeZoneCB, i18n("<p>Sets the time zone the camera was set to "
+                    "during photo shooting, so that the time stamps of the images "
+                    "can be converted to GMT to match the GPS time reference.\n"
+                    "Note: positive offsets count eastwards from zero longitude (GMT), "
+                    "they are 'ahead of time'."));
 
     d->interpolateBox = new QCheckBox(i18n("Interpolate"), settingsBox);
-    QWhatsThis::add(d->interpolateBox, i18n("<p>Set on this option to interpolate GPS points "
-                    "witch are not matches properly with the GPX data file."));
+    QWhatsThis::add(d->interpolateBox, i18n("<p>Set this option to interpolate GPS track points "
+                    "which are not closely matched to the GPX data file."));
 
-    d->maxTimeLabel = new QLabel(i18n("Max. distance time:"), settingsBox);
+    d->maxTimeLabel = new QLabel(i18n("Difference in min.:"), settingsBox);
     d->maxTimeInput = new KIntSpinBox(0, 240, 1, 15, 10, settingsBox);
-    QWhatsThis::add(d->maxTimeInput, i18n("<p>Set here the maximum distance time in minutes "
-                    "to get matched points from GPX file around a GPS point to interpolate."));
+    QWhatsThis::add(d->maxTimeInput, i18n("<p>Sets the maximum time difference in minutes (240 max.)"
+                    " to interpolate GPX file points to image time data."));
 
-    settingsBoxLayout->addMultiCellWidget(loadGPXButton, 0, 0, 0, 1);     
-    settingsBoxLayout->addMultiCellWidget(gpxFileLabel, 1, 1, 0, 1);     
-    settingsBoxLayout->addMultiCellWidget(d->gpxFileName, 2, 2, 0, 1);     
-    settingsBoxLayout->addMultiCellWidget(d->gpxPointsLabel, 3, 3, 0, 1);     
-    settingsBoxLayout->addMultiCellWidget(line, 4, 4, 0, 1);     
-    settingsBoxLayout->addMultiCellWidget(maxGapLabel, 5, 5, 0, 0); 
-    settingsBoxLayout->addMultiCellWidget(d->maxGapInput, 5, 5, 1, 1); 
-    settingsBoxLayout->addMultiCellWidget(timeZoneLabel, 6, 6, 0, 0); 
-    settingsBoxLayout->addMultiCellWidget(d->timeZoneCB, 6, 6, 1, 1); 
-    settingsBoxLayout->addMultiCellWidget(d->interpolateBox, 7, 7, 0, 1); 
-    settingsBoxLayout->addMultiCellWidget(d->maxTimeLabel, 8, 8, 0, 0); 
-    settingsBoxLayout->addMultiCellWidget(d->maxTimeInput, 8, 8, 1, 1); 
+    settingsBoxLayout->addMultiCellWidget(loadGPXButton, 0, 0, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(gpxFileLabel, 1, 1, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(d->gpxFileName, 2, 2, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(d->gpxPointsLabel, 3, 3, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(line, 4, 4, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(maxGapLabel, 5, 5, 0, 0);
+    settingsBoxLayout->addMultiCellWidget(d->maxGapInput, 5, 5, 1, 1);
+    settingsBoxLayout->addMultiCellWidget(timeZoneLabel, 6, 6, 0, 0);
+    settingsBoxLayout->addMultiCellWidget(d->timeZoneCB, 6, 6, 1, 1);
+    settingsBoxLayout->addMultiCellWidget(d->interpolateBox, 7, 7, 0, 1);
+    settingsBoxLayout->addMultiCellWidget(d->maxTimeLabel, 8, 8, 0, 0);
+    settingsBoxLayout->addMultiCellWidget(d->maxTimeInput, 8, 8, 1, 1);
 
     // ---------------------------------------------------------------
 
-    mainLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 2);
-    mainLayout->addMultiCellWidget(d->listView, 1, 3, 0, 1);
-    mainLayout->addMultiCellWidget(settingsBox, 1, 1, 2, 2);
+    mainLayout->addMultiCellWidget(d->listView, 0, 2, 0, 1);
+    mainLayout->addMultiCellWidget(settingsBox, 0, 1, 2, 2);
     mainLayout->setColStretch(1, 10);
-    mainLayout->setRowStretch(3, 10);
+    mainLayout->setRowStretch(2, 10);
 
     // ---------------------------------------------------------------
     // About data and help button.
 
     d->about = new KIPIPlugins::KPAboutData(I18N_NOOP("GPS Sync"),
-                                            NULL,
+                                            0,
                                             KAboutData::License_GPL,
-                                            I18N_NOOP("A Plugin to synchronize pictures metadata with a GPS device"),
-                                            "(c) 2006-2007, Gilles Caulier");
+                                            I18N_NOOP("A plugin to synchronize images' metadata with a GPS device"),
+                                            "(c) 2006-2008, Gilles Caulier");
 
     d->about->addAuthor("Gilles Caulier", I18N_NOOP("Author and Maintainer"),
-                        "caulier dot gilles at kdemail dot net");
+                        "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("GPS Sync Handbook"),
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
                                  this, SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
@@ -289,6 +289,11 @@ void GPSSyncDialog::setImages( const KURL::List& images )
 {
     for( KURL::List::ConstIterator it = images.begin(); it != images.end(); ++it )
         new GPSListViewItem(d->listView, d->listView->lastItem(), *it);
+
+    KIO::PreviewJob *thumbnailJob = KIO::filePreview(images, 64);
+
+    connect(thumbnailJob, SIGNAL(gotPreview(const KFileItem*, const QPixmap&)),
+            this, SLOT(slotGotThumbnail(const KFileItem*, const QPixmap&)));
 }
 
 void GPSSyncDialog::slotLoadGPXFile()
@@ -305,7 +310,7 @@ void GPSSyncDialog::slotLoadGPXFile()
     if (!ret)
     {
         KMessageBox::error(this, i18n("Cannot parse %1 GPX file!")
-                           .arg(loadGPXFile.fileName()), i18n("GPS Sync"));    
+                           .arg(loadGPXFile.fileName()), i18n("GPS Sync"));
         enableButton(User1, false);
         return;
     }
@@ -313,7 +318,7 @@ void GPSSyncDialog::slotLoadGPXFile()
     if (d->gpxParser.numPoints() <= 0)
     {
         KMessageBox::sorry(this, i18n("The %1 GPX file do not have a date-time track to use!")
-                           .arg(loadGPXFile.fileName()), i18n("GPS Sync"));    
+                           .arg(loadGPXFile.fileName()), i18n("GPS Sync"));
         enableButton(User1, false);
         return;
     }
@@ -327,7 +332,7 @@ void GPSSyncDialog::slotLoadGPXFile()
 void GPSSyncDialog::closeEvent(QCloseEvent *e)
 {
     if (!e) return;
-    if (!promptUserClose()) 
+    if (!promptUserClose())
     {
         e->ignore();
         return;
@@ -351,23 +356,23 @@ bool GPSSyncDialog::promptUserClose()
     QListViewItemIterator it( d->listView );
     int dirty = 0;
 
-    while ( it.current() ) 
+    while ( it.current() )
     {
         GPSListViewItem *item = (GPSListViewItem*) it.current();
         if (item->isDirty())
             dirty++;
-	    
+
         ++it;
     }
 
     if (dirty > 0)
     {
-        QString msg = i18n("1 picture from the list isn't updated.",
-                           "%n pictures from the list isn't updated.", dirty);
+        QString msg = i18n("1 image from the list is not updated.",
+                           "%n images from the list are not updated.", dirty);
 
         if (KMessageBox::No == KMessageBox::warningYesNo(this,
                      i18n("<p>%1\n"
-                          "Do you want really to close this window without applying changes?</p>")
+                          "Do you really want to close this window without applying changes?</p>")
                           .arg(msg)))
             return false;
     }
@@ -380,10 +385,10 @@ void GPSSyncDialog::readSettings()
     KConfig config("kipirc");
     config.setGroup("GPS Sync Settings");
     d->maxGapInput->setValue(config.readNumEntry("Max Gap Time", 30));
-    d->timeZoneCB->setCurrentItem(config.readNumEntry("Time Zone", 12));
+    d->timeZoneCB->setCurrentItem(config.readNumEntry("Time Zone", 16));  // GMT+00:00
     d->interpolateBox->setChecked(config.readBoolEntry("Interpolate", false));
     d->maxTimeInput->setValue(config.readNumEntry("Max Inter Dist Time", 15));
-    
+
     d->maxTimeLabel->setEnabled(d->interpolateBox->isChecked());
     d->maxTimeInput->setEnabled(d->interpolateBox->isChecked());
     resize(configDialogSize(config, QString("GPS Sync Dialog")));
@@ -407,16 +412,23 @@ void GPSSyncDialog::slotUser1()
     int itemsUpdated = 0;
 
     QListViewItemIterator it( d->listView );
-    while ( it.current() ) 
+    while ( it.current() )
     {
-        GPSListViewItem *item = (GPSListViewItem*) it.current();
+        GPSListViewItem *item = dynamic_cast<GPSListViewItem*>(it.current());
         GPSDataContainer gpsData;
+        QString tz = d->timeZoneCB->currentText();
+        int hh     = QString(QString(tz[4])+QString(tz[5])).toInt();
+        int mm     = QString(QString(tz[7])+QString(tz[8])).toInt();
+        int offset = hh*3600 + mm*60;
 
-        if (d->gpxParser.matchDate(item->getDateTime(), 
+        if (tz[3] == QChar('-'))
+            offset = (-1)*offset;
+
+        if (d->gpxParser.matchDate(item->dateTime(),
                                    d->maxGapInput->value(),
-                                   d->timeZoneCB->currentItem()-12,
+                                   offset,
                                    d->interpolateBox->isChecked(),
-                                   d->maxTimeInput->value()*60, 
+                                   d->maxTimeInput->value()*60,
                                    gpsData))
         {
             item->setGPSInfo(gpsData);
@@ -428,17 +440,17 @@ void GPSSyncDialog::slotUser1()
     if (itemsUpdated == 0)
     {
         KMessageBox::sorry(this, i18n("Cannot find pictures to correlate with GPX file data."),
-                           i18n("GPS Sync"));    
+                           i18n("GPS Sync"));
         return;
     }
 
-    QString msg = i18n("GPS data of 1 picture have been updated on the list using the GPX data file.",
-                       "GPS data of %n pictures have been updated on the list using the GPX data file.",
+    QString msg = i18n("GPS data of 1 image have been updated on the list using the GPX data file.",
+                       "GPS data of %n images have been updated on the list using the GPX data file.",
                        itemsUpdated);
     msg += '\n';
-    msg += i18n("Press <b>Apply</b> button to update pictures metadata.");
+    msg += i18n("Press Apply button to update images metadata.");
 
-    KMessageBox::information(this, msg, i18n("GPS Sync"));    
+    KMessageBox::information(this, msg, i18n("GPS Sync"));
 }
 
 // Start the GPS coordinates editor dialog.
@@ -446,15 +458,15 @@ void GPSSyncDialog::slotUser2()
 {
     if (!d->listView->currentItem())
     {
-        KMessageBox::information(this, i18n("Please, select at least one picture from "
-                     "the list to edit GPS coordinates manually."), i18n("GPS Sync"));    
+        KMessageBox::information(this, i18n("Please, select at least one image from "
+                     "the list to edit GPS coordinates manually."), i18n("GPS Sync"));
         return;
     }
 
-    GPSListViewItem* item = (GPSListViewItem*)d->listView->currentItem();
+    GPSListViewItem *item = dynamic_cast<GPSListViewItem*>(d->listView->currentItem());
 
-    GPSEditDialog dlg(this, item->getGPSInfo(), 
-                      item->getUrl().fileName(),
+    GPSEditDialog dlg(this, item->GPSInfo(),
+                      item->url().fileName(),
                       item->hasGPSInfo());
 
     if (dlg.exec() == KDialogBase::Accepted)
@@ -465,7 +477,7 @@ void GPSSyncDialog::slotUser2()
         {
             if (it.current()->isSelected())
             {
-                GPSListViewItem *selItem = (GPSListViewItem*)it.current();
+                GPSListViewItem *selItem = dynamic_cast<GPSListViewItem*>(it.current());
                 selItem->setGPSInfo(dlg.getGPSInfo(), true, true);
             }
             ++it;
@@ -478,8 +490,8 @@ void GPSSyncDialog::slotUser3()
 {
     if (!d->listView->currentItem())
     {
-        KMessageBox::information(this, i18n("Please, select at least one picture from "
-                     "the list to remove GPS coordinates."), i18n("GPS Sync"));    
+        KMessageBox::information(this, i18n("Please, select at least one image from "
+                     "the list to remove GPS coordinates."), i18n("GPS Sync"));
         return;
     }
 
@@ -489,7 +501,7 @@ void GPSSyncDialog::slotUser3()
     {
         if (it.current()->isSelected())
         {
-            GPSListViewItem *selItem = (GPSListViewItem*)it.current();
+            GPSListViewItem *selItem = dynamic_cast<GPSListViewItem*>(it.current());
             selItem->eraseGPSInfo();
         }
         ++it;
@@ -501,21 +513,36 @@ void GPSSyncDialog::slotApply()
     KURL::List images;
 
     QListViewItemIterator it( d->listView );
-    while ( it.current() ) 
+    while ( it.current() )
     {
-        GPSListViewItem *item = (GPSListViewItem*) it.current();
-        d->listView->setSelected(item, true);
-        d->listView->ensureItemVisible(item);
-        item->writeGPSInfoToFile();
-        images.append(item->getUrl());
+        GPSListViewItem *selItem = dynamic_cast<GPSListViewItem*>(it.current());
+        d->listView->setSelected(selItem, true);
+        d->listView->ensureItemVisible(selItem);
+        selItem->writeGPSInfoToFile();
+        images.append(selItem->url());
         ++it;
         kapp->processEvents();
     }
 
-    // We use kipi interface refreshImages() method to tell to host than 
+    // We use kipi interface refreshImages() method to tell to host than
     // metadata from pictures have changed and need to be re-readed.
-    
+
     d->interface->refreshImages(images);
 }
 
+void GPSSyncDialog::slotGotThumbnail(const KFileItem *item, const QPixmap& pix)
+{
+    QListViewItemIterator it(d->listView);
+
+    while (it.current())
+    {
+        GPSListViewItem *selItem = dynamic_cast<GPSListViewItem*>(it.current());
+        if (selItem->url() == item->url())
+        {
+            selItem->setPixmap(0, pix);
+        }
+        ++it;
+    }
+}
+
 }  // NameSpace KIPIGPSSyncPlugin
