@@ -1,10 +1,13 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
- * Date   : 2006-05-16
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2006-05-16
  * Description : a plugin to synchronize pictures with 
  *               a GPS device.
  *
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,11 +51,10 @@
 #include "gpsdatacontainer.h"
 #include "gpseditdialog.h"
 #include "gpssyncdialog.h"
-#include "plugin_gpssync.h"
-#include "plugin_gpssync.moc"
 #include "kmlexport.h"
 #include "kmlexportconfig.h"
-
+#include "plugin_gpssync.h"
+#include "plugin_gpssync.moc"
 
 typedef KGenericFactory<Plugin_GPSSync> Factory;
 
@@ -68,12 +70,12 @@ void Plugin_GPSSync::setup( QWidget* widget )
 {
     KIPI::Plugin::setup( widget );
 
-    m_action_geolocalization = new KActionMenu(i18n("Geolocalization"),
+    m_action_geolocation = new KActionMenu(i18n("Geolocation"),
                                0,
                                actionCollection(),
-                               "geolocalization");
+                               "geolocation");
 
-    m_action_geolocalization->insert(new KAction (i18n("Correlator..."),
+    m_action_geolocation->insert(new KAction (i18n("Correlator..."),
                                      "gpsimagetag",
                                      0,     
                                      this,
@@ -81,32 +83,32 @@ void Plugin_GPSSync::setup( QWidget* widget )
                                      actionCollection(),
                                      "gpssync"));
 
-    m_action_geolocalization->insert(new KAction (i18n("Edit Coordinates..."),
+    m_action_geolocation->insert(new KAction (i18n("Edit Coordinates..."),
+                                     0,
                                      0,
-                                     0,     
                                      this,
                                      SLOT(slotGPSEdit()),
                                      actionCollection(),
                                      "gpsedit"));
 
-    m_action_geolocalization->insert(new KAction (i18n("Remove Coordinates..."),
+    m_action_geolocation->insert(new KAction (i18n("Remove Coordinates..."),
+                                     0,
                                      0,
-                                     0,     
                                      this,
                                      SLOT(slotGPSRemove()),
                                      actionCollection(),
                                      "gpsremove"));
 
-    addAction( m_action_geolocalization );
+    addAction( m_action_geolocation );
 
    // this is our action shown in the menubar/toolbar of the mainwindow
     m_actionKMLExport = new KAction (i18n("KML Export..."),
-                                     "www",	// icon
-                                   0,	// do never set shortcuts from plugins.
-                                   this,
-                                   SLOT(slotKMLExport()),
-                                   actionCollection(),
-                                   "kmlexport");
+                                     "www", // icon
+                                     0,     // do never set shortcuts from plugins.
+                                     this,
+                                     SLOT(slotKMLExport()),
+                                     actionCollection(),
+                                     "kmlexport");
 
     addAction( m_actionKMLExport );
 
@@ -119,10 +121,10 @@ void Plugin_GPSSync::setup( QWidget* widget )
     }
 
     KIPI::ImageCollection selection = m_interface->currentSelection();
-    m_action_geolocalization->setEnabled( selection.isValid() && !selection.images().isEmpty() );
+    m_action_geolocation->setEnabled( selection.isValid() && !selection.images().isEmpty() );
 
     connect( m_interface, SIGNAL(selectionChanged(bool)),
-             m_action_geolocalization, SLOT(setEnabled(bool)));
+             m_action_geolocation, SLOT(setEnabled(bool)));
 }
 
 bool Plugin_GPSSync::checkBinaries(QString &gpsBabelVersion)
@@ -213,15 +215,15 @@ void Plugin_GPSSync::slotGPSEdit()
         KURL::List  imageURLs = images.images();
         KURL::List  updatedURLs;
         QStringList errorFiles;
-    
+
         for( KURL::List::iterator it = imageURLs.begin() ; 
             it != imageURLs.end(); ++it)
         {
             KURL url = *it;
-        
+
             // We only add all JPEG files as R/W because Exiv2 can't yet 
             // update metadata on others file formats.
-        
+
             QFileInfo fi(url.path());
             QString ext = fi.extension(false).upper();
             bool ret = false;
@@ -246,7 +248,7 @@ void Plugin_GPSSync::slotGPSEdit()
 
         // We use kipi interface refreshImages() method to tell to host than 
         // metadata from pictures have changed and need to be re-readed.
-        
+
         m_interface->refreshImages(updatedURLs);
 
         if (!errorFiles.isEmpty())
@@ -269,7 +271,7 @@ void Plugin_GPSSync::slotGPSRemove()
 
     if (KMessageBox::warningYesNo(
                      kapp->activeWindow(),
-                     i18n("Geographical coordinates will be definitivly removed from all current selected pictures.\n"
+                     i18n("Geographical coordinates will be definitively removed from all selected images.\n"
                           "Do you want to continue ?"),
                      i18n("Remove Geographical Coordinates")) != KMessageBox::Yes)
         return;
@@ -282,10 +284,10 @@ void Plugin_GPSSync::slotGPSRemove()
          it != imageURLs.end(); ++it)
     {
         KURL url = *it;
-    
+
         // We only add all JPEG files as R/W because Exiv2 can't yet 
         // update metadata on others file formats.
-    
+
         QFileInfo fi(url.path());
         QString ext = fi.extension(false).upper();
         bool ret = false;
@@ -297,7 +299,7 @@ void Plugin_GPSSync::slotGPSRemove()
             ret &= exiv2Iface.removeGPSInfo();
             ret &= exiv2Iface.save(url.path());
         }
-        
+
         if (!ret)
             errorFiles.append(url.fileName());
         else 
@@ -306,7 +308,7 @@ void Plugin_GPSSync::slotGPSRemove()
 
     // We use kipi interface refreshImages() method to tell to host than 
     // metadata from pictures have changed and need to be re-readed.
-    
+
     m_interface->refreshImages(updatedURLs);
 
     if (!errorFiles.isEmpty())
@@ -319,19 +321,21 @@ void Plugin_GPSSync::slotGPSRemove()
     }
 }
 
-
 void Plugin_GPSSync::slotKMLExport()
 {
     KIPI::ImageCollection selection = m_interface->currentSelection();
 
-    if ( !selection.isValid() ) {
+    if ( !selection.isValid() ) 
+    {
         kdDebug( 51000) << "No Selection!" << endl;
     }
-    else {
-        KIPIGPSSyncPlugin::KMLExportConfig *kmlExportConfigGui = new KIPIGPSSyncPlugin::KMLExportConfig( kapp->activeWindow(), i18n("KMLExport").ascii());
-        connect(kmlExportConfigGui, SIGNAL(okButtonClicked()), this, SLOT(slotKMLGenerate()));
+    else 
+    {
+        KIPIGPSSyncPlugin::KMLExportConfig *kmlExportConfigGui = new KIPIGPSSyncPlugin::KMLExportConfig(
+                                                                 kapp->activeWindow(), i18n("KMLExport").ascii());
+        connect(kmlExportConfigGui, SIGNAL(okButtonClicked()), 
+                this, SLOT(slotKMLGenerate()));
         kmlExportConfigGui->show();
-
     }
 }
 
@@ -344,10 +348,9 @@ void Plugin_GPSSync::slotKMLGenerate()
     myExport.generate();
 }
 
-
 KIPI::Category Plugin_GPSSync::category( KAction* action ) const
 {
-    if ( action == m_action_geolocalization )
+    if ( action == m_action_geolocation )
        return KIPI::IMAGESPLUGIN;
     if ( action == m_actionKMLExport )
        return KIPI::EXPORTPLUGIN;
