@@ -8,8 +8,13 @@
  *               actions using threads
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2004-2007 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
+ * NOTE: Do not use kdDebug() in this implementation because 
+ *       it will be multithreaded. Use qDebug() instead. 
+ *       See B.K.O #133026 for details.
+ *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
@@ -22,13 +27,6 @@
  * 
  * ============================================================ */
 
-// C Ansi includes.
-
-extern "C"
-{
-#include <unistd.h>
-}
-
 // Qt includes.
 
 #include <qapplication.h>
@@ -38,7 +36,6 @@ extern "C"
 // KDE includes.
 
 #include <kdebug.h>
-#include <kstandarddirs.h>
 
 // Local includes.
 
@@ -54,18 +51,12 @@ namespace KIPIJPEGLossLessPlugin
 ActionThread::ActionThread( KIPI::Interface* interface, QObject *parent)
             : QThread(), m_parent(parent), m_interface( interface )
 {
-    // Create a KIPI JPEGLossLess plugin temporary folder in KDE tmp directory.
-    KStandardDirs dir;
-    m_tmpFolder = dir.saveLocation("tmp", "kipi-jpeglosslessplugin-" +
-                                   QString::number(getpid()) + "/");
 }
 
 ActionThread::~ActionThread()
 {
     // cancel the thread
     cancel();
-    // delete the temporary folder
-    Utils::deleteDir(m_tmpFolder);
     // wait for the thread to finish
     wait();
 }
@@ -77,6 +68,13 @@ void ActionThread::rotate(const KURL::List& urlList, RotateAction val)
     {
         KIPI::ImageInfo info = m_interface->info( *it );
 
+        /*
+        Removing this code:
+         - for JPEGs, jpegtransform is using the Exiv2Iface and matrix multiplication
+           to compute the mathematically correct rotation (taking flip operations into account,
+           the code below only angles). Metadata tag is reset.
+         - For ImageMagick, no metadata is taken into account, and no metadata is changed!
+           Angle from host application still applies.
         // Don't use the host angle in case of auto-rotation (Rot0)
         if (val != Rot0)
         {
@@ -105,6 +103,7 @@ void ActionThread::rotate(const KURL::List& urlList, RotateAction val)
             else
                 val = Rot0;
         }
+        */
 
         Task *t      = new Task;
         t->filePath  = QDeepCopy<QString>((*it).path()); //deep copy
@@ -174,11 +173,11 @@ void ActionThread::run()
                 d->fileName = t->filePath;
                 d->starting = true;
                 QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
-    
+
                 bool result = true;
                 ImageRotate imageRotate;
-                result = imageRotate.rotate(t->filePath, t->rotAction, m_tmpFolder, errString);
-    
+                result = imageRotate.rotate(t->filePath, t->rotAction, errString);
+
                 EventData *r = new EventData;
                 r->action    = Rotate;
                 r->fileName  = t->filePath;
@@ -195,7 +194,7 @@ void ActionThread::run()
                 QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
                 
                 ImageFlip imageFlip;
-                bool result = imageFlip.flip(t->filePath, t->flipAction, m_tmpFolder, errString);
+                bool result = imageFlip.flip(t->filePath, t->flipAction, errString);
     
                 EventData *r = new EventData;
                 r->action    = Flip;
@@ -213,7 +212,7 @@ void ActionThread::run()
                 QApplication::postEvent(m_parent, new QCustomEvent(QEvent::User, d));
     
                 ImageGrayScale imageGrayScale;
-                bool result = imageGrayScale.image2GrayScale(t->filePath, m_tmpFolder, errString);
+                bool result = imageGrayScale.image2GrayScale(t->filePath, errString);
     
                 EventData *r = new EventData;
                 r->action    = GrayScale;
@@ -225,9 +224,8 @@ void ActionThread::run()
             }
             default: 
             {
-                kdWarning( 51000 ) << "KIPIJPEGLossLessPlugin:ActionThread: "
-                                   << "Unknown action specified"
-                                   << endl;
+                qDebug("KIPIJPEGLossLessPlugin:ActionThread: "
+                       "Unknown action specified");
                 delete d;
             }
         }
