@@ -1,18 +1,19 @@
 /* ============================================================
- * Authors: Ralf Hoelzer <kde at ralfhoelzer.com>
- *          Marcel Wiesweg <marcel.wiesweg@gmx.de>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2004-06-08
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-06-08
+ * Description : Loss less JPEG files transformations.
  * 
- * Copyright 2004 by  Ralf Hoelzer
- * Copyright 2004-2005 by Marcel Wiesweg
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2004      by  Ralf Hoelzer <kde at ralfhoelzer.com>
+ * Copyright (C) 2004-2005 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,9 +29,9 @@
 
 #include <qstring.h>
 
-// Local includes.
+// LibKExiv2 includes. 
 
-#include "exiv2iface.h"
+#include <libkexiv2/kexiv2.h>
 
 namespace KIPIJPEGLossLessPlugin
 {
@@ -72,14 +73,14 @@ public:
         set( 1, 0, 0, 1 );
    }
     
-   Matrix &operator*=(Matrix &ma)
+   Matrix &operator*=(const Matrix &ma)
    {
         set( ma.m[0][0]*m[0][0] + ma.m[0][1]*m[1][0],  ma.m[0][0]*m[0][1] + ma.m[0][1]*m[1][1],
              ma.m[1][0]*m[0][0] + ma.m[1][1]*m[1][0],  ma.m[1][0]*m[0][1] + ma.m[1][1]*m[1][1] );
         return *this;
    }
     
-   bool operator==(Matrix &ma)
+   bool operator==(const Matrix &ma) const
    {
         return m[0][0]==ma.m[0][0] &&
                m[0][1]==ma.m[0][1] &&
@@ -87,19 +88,19 @@ public:
                m[1][1]==ma.m[1][1];
    }
     
-   bool operator!=(Matrix &ma) 
+   bool operator!=(const Matrix &ma) const
    { 
         return !(*this==ma); 
    }
     
-   static Matrix none;                   //( 1,  0,  0,  1)
-   static Matrix rotate90;               //( 0, -1,  1,  0)
-   static Matrix rotate180;              //(-1,  0,  0, -1)
-   static Matrix rotate270;              //( 0,  1, -1,  0)
-   static Matrix flipHorizontal;         //(-1,  0,  0,  1)
-   static Matrix flipVertical;           //( 1,  0,  0, -1)
-   static Matrix rotate90flipHorizontal; //( 0,  1,  1,  0), first rotate, then flip
-   static Matrix rotate90flipVertical;   //( 0, -1, -1,  0), first rotate, then flip
+   static const Matrix none;                   //( 1,  0,  0,  1)
+   static const Matrix rotate90;               //( 0, -1,  1,  0)
+   static const Matrix rotate180;              //(-1,  0,  0, -1)
+   static const Matrix rotate270;              //( 0,  1, -1,  0)
+   static const Matrix flipHorizontal;         //(-1,  0,  0,  1)
+   static const Matrix flipVertical;           //( 1,  0,  0, -1)
+   static const Matrix rotate90flipHorizontal; //( 0,  1,  1,  0), first rotate, then flip
+   static const Matrix rotate90flipVertical;   //( 0, -1, -1,  0), first rotate, then flip
 
 protected:
 
@@ -124,7 +125,7 @@ bool transformJPEG(const QString& src, const QString& dest, Matrix &action, QStr
 
 void convertTransform(Matrix &action, JXFORM_CODE &flip, JXFORM_CODE &rotate);
 
-void getExifAction(Matrix &action, KIPIPlugins::Exiv2Iface::ImageOrientation exifOrientation);
+void getExifAction(Matrix &action, KExiv2Iface::KExiv2::ImageOrientation exifOrientation);
 
 }  // NameSpace KIPIJPEGLossLessPlugin
 
