@@ -43,6 +43,7 @@
 
 // Local includes.
 
+#include "pluginsversion.h"
 #include "kpaboutdata.h"
 #include "cameraselection.h"
 #include "gpiface.h"
@@ -57,7 +58,7 @@ CameraSelection::CameraSelection(QWidget* parent)
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("KameraKlient"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Digital camera interface Kipi plugin"),
                                            "(c) 2003-2004, Renchi Raju\n"
@@ -72,7 +73,7 @@ CameraSelection::CameraSelection(QWidget* parent)
     helpButton_ = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("KameraKlient Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     helpButton_->setPopup( helpMenu->menu() );
 
     QWidget *page = new QWidget(this);
@@ -82,29 +83,6 @@ CameraSelection::CameraSelection(QWidget* parent)
 
     //---------------------------------------------
 
-    QFrame *headerFrame = new QFrame( page );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Camera Selection"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    topLayout->addWidget( headerFrame );
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    //---------------------------------------------
-
     QGroupBox* mainBox = new QGroupBox(page);
     mainBox->setTitle(i18n("Camera Configuration"));
     mainBox->setColumnLayout(0, Qt::Vertical );
