@@ -4,8 +4,8 @@
  * Date  : 2003-01-21
  * Description :
  *
- * Copyright 2003 by Renchi Raju
- * Copyright 2004 by Tudor Calin
+ * Copyright 2003 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright 2004 by Tudor Calin <tudor@1xtech.com>
  *
  * Update : 08/28/2003 - Gilles Caulier <caulier.gilles@free.fr>
  *          Add standard shortcuts and toolbars KDE menu entry.
@@ -109,29 +109,6 @@ CameraUI::CameraUI() : QWidget()
     //---------------------------------------------
 
     QVBoxLayout *dvlay = new QVBoxLayout( this, 6 );
-    QFrame *headerFrame = new QFrame( this );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Digital Camera interface"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    dvlay->addWidget( headerFrame );
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    //---------------------------------------------
-
     QHBoxLayout* mMainBoxLayout = new QHBoxLayout(dvlay);
     mMainBoxLayout->setResizeMode(QLayout::FreeResize);
     QVBoxLayout* mLeftBoxLayout = new QVBoxLayout(mMainBoxLayout, 0);
@@ -168,7 +145,7 @@ CameraUI::CameraUI() : QWidget()
     mBtnBoxLayout->addWidget(mhelpButton);
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("KameraKlient"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Digital camera interface Kipi plugin"),
                                            "(c) 2003-2004, Renchi Raju\n"
@@ -182,7 +159,7 @@ CameraUI::CameraUI() : QWidget()
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("KameraKlient Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     mhelpButton->setPopup( helpMenu->menu() );
 
     // create Camera Box-----------------------------------------------------------------------
