@@ -1,21 +1,23 @@
 /* ============================================================
- * Authors     : Gilles Caulier
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-18
  * Description : EXIF device settings page.
- * 
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ *
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *  
+ * 
  * ============================================================ */
 
 // C++ includes.
@@ -37,6 +39,7 @@
 #include <knuminput.h>
 #include <klineedit.h>
 #include <kseparator.h>
+#include <kactivelabel.h>
 
 // LibKExiv2 includes. 
 
@@ -158,8 +161,11 @@ EXIFDevice::EXIFDevice(QWidget* parent)
     QWhatsThis::add(d->deviceTypeCB, i18n("<p>Select here the image input equipment type used to "
                                      "take the picture."));
 
-    QLabel *warning = new QLabel(i18n("<b>Warning: EXIF Makernotes can be unreadable if you set "
-                                      "wrong device manufacturer/model description.</b>"), parent);
+    KActiveLabel *warning = new KActiveLabel(i18n("<b>Warning: EXIF <b><a href="
+                 "'http://en.wikipedia.org/wiki/Exchangeable_image_file_format#MakerNote_Information'>"
+                 "Makernotes</a></b> can be unreadable if you set "
+                 "wrong device manufacturer/model description.</b>"), parent);
+
     KSeparator *line = new KSeparator(Horizontal, parent);
     grid->addMultiCellWidget(warning, 3, 3, 0, 5);
     grid->addMultiCellWidget(line, 4, 4, 0, 5);
@@ -329,10 +335,13 @@ EXIFDevice::EXIFDevice(QWidget* parent)
 
     // --------------------------------------------------------
 
-    QLabel *exifNote = new QLabel(i18n("<b>Note: EXIF text tags annoted by (*) only support printable "
-                                       "ASCII characters set.</b>"), parent);
-    grid->addMultiCellWidget(exifNote, 15, 15, 0, 5);
+    KActiveLabel *note = new KActiveLabel(i18n("<b>Note: "
+                 "<b><a href='http://en.wikipedia.org/wiki/EXIF'>EXIF</a></b> "
+                 "text tags marked by (*) only support printable "
+                 "<b><a href='http://en.wikipedia.org/wiki/Ascii'>ASCII</a></b> "
+                 "characters set.</b>"), parent);
 
+    grid->addMultiCellWidget(note, 15, 15, 0, 5);
     grid->setColStretch(1, 10);                     
     grid->setColStretch(5, 10);                     
     grid->setRowStretch(16, 10);                     
