@@ -1,21 +1,23 @@
 /* ============================================================
- * Authors     : Gilles Caulier 
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
  * Date        : 2006-10-11
  * Description : a plugin to edit pictures metadata
  *
- * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // KDE includes.
@@ -120,7 +122,7 @@ void Plugin_MetadataEdit::setup( QWidget* widget )
 
     m_actionMetadataEdit->popupMenu()->insertSeparator();
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Edit Comments..."),
+    m_actionMetadataEdit->insert(new KAction (i18n("Edit Captions..."),
                                      0,
                                      0,     
                                      this,
@@ -128,7 +130,7 @@ void Plugin_MetadataEdit::setup( QWidget* widget )
                                      actionCollection(),
                                      "editcomments"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Remove Comments..."),
+    m_actionMetadataEdit->insert(new KAction (i18n("Remove Captions..."),
                                      0,
                                      0,     
                                      this,
@@ -503,9 +505,9 @@ void Plugin_MetadataEdit::slotEditComments()
     {
         KMessageBox::informationList(
                      kapp->activeWindow(),
-                     i18n("Unable to set comments like picture metadata from:"),
+                     i18n("Unable to set captions as image metadata from:"),
                      errorFiles,
-                     i18n("Edit Pictures Comments"));  
+                     i18n("Edit Image Caption"));  
     }
 }
 
@@ -570,9 +572,9 @@ void Plugin_MetadataEdit::slotRemoveComments()
     {
         KMessageBox::informationList(
                      kapp->activeWindow(),
-                     i18n("Unable to remove Comments like picture metadata from:"),
+                     i18n("Unable to remove caption as image metadata from:"),
                      errorFiles,
-                     i18n("Remove Pictures Comments"));  
+                     i18n("Remove Image Caption"));  
     }
 }
 
