@@ -1,24 +1,25 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-01-31
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-01-31
  * Description : a kipi plugin to convert Raw file in single 
  *               or batch mode.
  *
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // C ANSI Includes.
@@ -50,10 +51,12 @@ extern "C"
 #include <kdebug.h>
 #include <kmessagebox.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawbinary.h>
+
 // Local includes.
 
-#include "rawfiles.h"
-#include "dcrawbinary.h"
 #include "singledialog.h"
 #include "batchdialog.h"
 #include "plugin_rawconverter.h"
@@ -73,7 +76,7 @@ Plugin_RawConverter::Plugin_RawConverter(QObject *parent, const char*, const QSt
 void Plugin_RawConverter::setup( QWidget* widget )
 {
     KIPI::Plugin::setup( widget );
-    singleAction_ = new KAction (i18n("Raw Image Converter (Single)..."),
+    singleAction_ = new KAction (i18n("Raw Image Converter..."),
                                  "rawconvertersingle",
                                  0,
                                  this,
@@ -81,7 +84,7 @@ void Plugin_RawConverter::setup( QWidget* widget )
                                  actionCollection(),
                                  "raw_converter_single");
 
-    batchAction_ = new KAction (i18n("Raw Images Converter (Batch)..."),
+    batchAction_ = new KAction (i18n("Batch Raw Converter..."),
                                  "rawconverterbatch",
                                  0,
                                  this,
@@ -113,7 +116,7 @@ Plugin_RawConverter::~Plugin_RawConverter()
 
 bool Plugin_RawConverter::isRAWFile(const QString& filePath)
 {
-    QString rawFilesExt(kipi_raw_file_extentions);
+    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
 
     QFileInfo fileInfo(filePath);
     if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
@@ -122,57 +125,18 @@ bool Plugin_RawConverter::isRAWFile(const QString& filePath)
     return false;
 }
 
-bool Plugin_RawConverter::checkBinaries(QString &dcrawVersion)
+bool Plugin_RawConverter::checkBinaries()
 {
-    KIPIRawConverterPlugin::DcrawBinary dcrawBinary;
-    dcrawVersion = dcrawBinary.version();
-
-    if (!dcrawBinary.isAvailable()) 
-    {
-        KMessageBox::information(
-                     kapp->activeWindow(),
-                     i18n("<qt><p>Unable to find the <b>%1</b> executable:<br>"
-                          "This program is required by this plugin to support "
-                          "Raw files decoding. "
-                          "Please check %2 installation on your computer.</p></qt>")
-                          .arg(dcrawBinary.path())
-                          .arg(dcrawBinary.path()),
-                     QString::null,
-                     QString::null,
-                     KMessageBox::Notify | KMessageBox::AllowLink);
-        return false;
-    }
-
-    if (!dcrawBinary.versionIsRight()) 
-    {
-        KMessageBox::information(
-                     kapp->activeWindow(),
-                     i18n("<qt><p><b>%1</b> executable isn't up to date:<br>"
-                          "The version %2 of %3 have been found on your computer. "
-                          "This version is too old to run properly with this plugin. "
-                          "Please check %4 installation on your computer.</p>"
-                          "<p>Note: at least, %5 version %6 is required by this "
-                          "plugin.</p></qt>")
-                          .arg(dcrawBinary.path())
-                          .arg(dcrawVersion)
-                          .arg(dcrawBinary.path())
-                          .arg(dcrawBinary.path())
-                          .arg(dcrawBinary.path())
-                          .arg(dcrawBinary.minimalVersion()),
-                     QString::null,
-                     QString::null,
-                     KMessageBox::Notify | KMessageBox::AllowLink);
-        return false;
-    }
-
-    return true;
+    KDcrawIface::DcrawBinary::instance()->checkSystem();
+    KDcrawIface::DcrawBinary::instance()->checkReport();
+    return KDcrawIface::DcrawBinary::instance()->isAvailable();
 }
 
 void Plugin_RawConverter::slotActivateSingle()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
 
-    if ( !interface )
+    if (!interface)
     {
         kdError( 51000 ) << "Kipi interface is null!" << endl;
         return;
@@ -181,11 +145,10 @@ void Plugin_RawConverter::slotActivateSingle()
     KIPI::ImageCollection images;
     images = interface->currentSelection();
 
-    if ( !images.isValid() )
+    if (!images.isValid())
         return;
 
-    QString dcrawVersion;
-    if (!checkBinaries(dcrawVersion)) 
+    if (!checkBinaries()) 
         return;
 
     if (!isRAWFile(images.images()[0].path()))
@@ -197,7 +160,7 @@ void Plugin_RawConverter::slotActivateSingle()
 
     KIPIRawConverterPlugin::SingleDialog *converter = 
         new KIPIRawConverterPlugin::SingleDialog(images.images()[0].path(), 
-            kapp->activeWindow(), dcrawVersion); 
+            kapp->activeWindow()); 
 
     converter->show();
 }
@@ -206,7 +169,7 @@ void Plugin_RawConverter::slotActivateBatch()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
 
-    if ( !interface )
+    if (!interface)
     {
         kdError( 51000 ) << "Kipi interface is null!" << endl;
         return;
@@ -215,15 +178,14 @@ void Plugin_RawConverter::slotActivateBatch()
     KIPI::ImageCollection images;
     images = interface->currentSelection();
 
-    if ( !images.isValid() )
+    if (!images.isValid())
         return;
 
-    QString dcrawVersion;
-    if (!checkBinaries(dcrawVersion)) 
+    if (!checkBinaries()) 
         return;
 
     KIPIRawConverterPlugin::BatchDialog *converter =
-        new KIPIRawConverterPlugin::BatchDialog(kapp->activeWindow(), dcrawVersion);
+        new KIPIRawConverterPlugin::BatchDialog(kapp->activeWindow());
 
     KURL::List urls = images.images();
     QStringList files;
@@ -248,4 +210,3 @@ KIPI::Category Plugin_RawConverter::category( KAction* action ) const
     kdWarning( 51000 ) << "Unrecognized action for plugin category identification" << endl;
     return KIPI::TOOLSPLUGIN; // no warning from compiler, please
 }
-
