@@ -165,7 +165,7 @@ bool RawDecodingIface::decodeRAWImage(const QString& filePath,
 
 bool RawDecodingIface::loadedFromDcraw(const QString& filePath, 
                                        QString& destPath, SaveSettingsWidget::OutputFormat outputFileFormat,
-                                       QByteArray imageData, int width, int height)
+                                       const QByteArray& imageData, int width, int height)
 {
     // -- Use a QImage instance to write IPTC preview and Exif thumbnail -------
 
@@ -190,11 +190,20 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
     // -- Write image data into destination file -------------------------------
 
     QByteArray ICCColorProfile = getICCProfilFromFile(m_rawDecodingSettings.outputColorSpace);
-    QString soft = QString("Kipi Raw Converter v.%1").arg(kipiplugins_version);
+    QString soft = QString("Kipi-plugins v.%1").arg(kipiplugins_version);
     QFileInfo fi(filePath);
     destPath = fi.dirPath(true) + QString("/") + ".kipi-rawconverter-tmp-" 
                                 + QString::number(::time(0));
 
+    // Metadata restoration and update.
+    KExiv2Iface::KExiv2 exiv2Iface;
+    exiv2Iface.load(filePath);
+    exiv2Iface.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
+    exiv2Iface.setImageDimensions(QSize(width, height));
+    exiv2Iface.setExifThumbnail(exifThumbnail);
+    exiv2Iface.setImagePreview(iptcPreview);
+    exiv2Iface.setExifTagString("Exif.Image.DocumentName", fi.fileName());
+
     switch(outputFileFormat)
     {
         case SaveSettingsWidget::OUTPUT_JPEG:
@@ -223,10 +232,17 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             cinfo.input_components = 3;
             cinfo.in_color_space   = JCS_RGB;
             jpeg_set_defaults(&cinfo);
-            // B.K.O #130996: set horizontal and vertical Subsampling factor 
-            // to 1 for a best quality of color picture compression. 
-            cinfo.comp_info[0].h_samp_factor = 1;
-            cinfo.comp_info[0].v_samp_factor = 1; 
+
+            // B.K.O #149578: set encoder horizontal and vertical chroma subsampling 
+            // factor to 2x1, 1x1, 1x1 (4:2:2) : Medium subsampling.
+            // See this page for details: http://en.wikipedia.org/wiki/Chroma_subsampling 
+            cinfo.comp_info[0].h_samp_factor = 2;
+            cinfo.comp_info[0].v_samp_factor = 1;
+            cinfo.comp_info[1].h_samp_factor = 1;
+            cinfo.comp_info[1].v_samp_factor = 1;
+            cinfo.comp_info[2].h_samp_factor = 1;
+            cinfo.comp_info[2].v_samp_factor = 1;
+
             jpeg_set_quality(&cinfo, 100, true);
             jpeg_start_compress(&cinfo, true);
 
@@ -243,15 +259,9 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             }
             
             jpeg_finish_compress(&cinfo);
+            jpeg_destroy_compress(&cinfo);
             fclose(f);
 
-            // Metadata restoration and update.
-            KExiv2Iface::KExiv2 exiv2Iface;
-            exiv2Iface.load(filePath);
-            exiv2Iface.setImageProgramId(QString("Kipi Raw Converter"), QString(kipiplugins_version));
-            exiv2Iface.setImageDimensions(QSize(width, height));
-            exiv2Iface.setExifThumbnail(exifThumbnail);
-            exiv2Iface.setExifTagString("Exif.Image.DocumentName", fi.fileName());
             exiv2Iface.save(destPath);
             break;
         }
@@ -298,15 +308,6 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             text.compression = PNG_TEXT_COMPRESSION_zTXt;
             png_set_text(png_ptr, info_ptr, &(text), 1);
 
-            // Metadata restoration and update.
-            KExiv2Iface::KExiv2 exiv2Iface;
-            exiv2Iface.load(filePath);
-            exiv2Iface.setImageProgramId(QString("Kipi Raw Converter"), QString(kipiplugins_version));
-            exiv2Iface.setImageDimensions(QSize(width, height));
-            exiv2Iface.setExifThumbnail(exifThumbnail);
-            exiv2Iface.setImagePreview(iptcPreview);
-            exiv2Iface.setExifTagString("Exif.Image.DocumentName", fi.fileName());
-
             // Store Exif data.
             QByteArray ba = exiv2Iface.getExif();
             const uchar ExifHeader[] = {0x45, 0x78, 0x69, 0x66, 0x00, 0x00};
@@ -373,15 +374,6 @@ bool RawDecodingIface::loadedFromDcraw(const QString& filePath,
             TIFFSetField(tif, TIFFTAG_ROWSPERSTRIP,    TIFFDefaultStripSize(tif, 0));
 
 
-            // Metadata restoration and update.
-            KExiv2Iface::KExiv2 exiv2Iface;
-            exiv2Iface.load(filePath);
-            exiv2Iface.setImageProgramId(QString("Kipi Raw Converter"), QString(kipiplugins_version));
-            exiv2Iface.setImageDimensions(QSize(width, height));
-            exiv2Iface.setExifThumbnail(exifThumbnail);
-            exiv2Iface.setImagePreview(iptcPreview);
-            exiv2Iface.setExifTagString("Exif.Image.DocumentName", fi.fileName());
-
             // Store Exif data.
             // TODO
 
@@ -582,7 +574,9 @@ size_t RawDecodingIface::copyString(char *destination, const char *source, const
         if (length != 0)
             *q='\0';
   
-        while (*p++ != '\0');
+        while (*p++ != '\0') {
+            ;
+        }
     }
     
     return((size_t) (p-source-1));
