@@ -7,7 +7,7 @@
  * Description : Raw converter single dialog
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,7 +42,6 @@ extern "C"
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qfileinfo.h>
-#include <qgroupbox.h>
 #include <qevent.h>
 #include <qpushbutton.h>
 #include <qfile.h>
@@ -89,68 +88,40 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
     
     QWidget *page = new QWidget( this );
     setMainWidget( page );
-    QGridLayout *mainLayout = new QGridLayout(page, 3, 1, 0, spacingHint());
-
-    // --------------------------------------------------------------
-
-    QFrame *headerFrame = new QFrame( page );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Raw Image Converter"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    mainLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("kipi_banner_left", KGlobal::dirs()->kde_default("data") + "kipi/data");
-    directory = KGlobal::dirs()->findResourceDir("kipi_banner_left", "banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    // --------------------------------------------------------------
+    QGridLayout *mainLayout = new QGridLayout(page, 1, 1, 0, spacingHint());
 
     m_previewWidget = new PreviewWidget(page);
-    mainLayout->addMultiCellWidget(m_previewWidget, 1, 3, 0, 0);
 
     // ---------------------------------------------------------------
 
-    m_rawSettingsGroup    = new QGroupBox(1, Qt::Vertical, i18n("RAW Decoding Settings"), page);
-    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(m_rawSettingsGroup, false, true, true);
-    m_saveSettingsBox     = new SaveSettingsWidget(page);
-
-    mainLayout->addMultiCellWidget(m_rawSettingsGroup, 1, 1, 1, 1);
-    mainLayout->addMultiCellWidget(m_saveSettingsBox, 2, 2, 1, 1);
+    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(page, false, true, true);
+    m_saveSettingsBox     = new SaveSettingsWidget(m_decodingSettingsBox);
+    m_decodingSettingsBox->insertTab(m_saveSettingsBox, i18n("Save settings"));
 
+    mainLayout->addMultiCellWidget(m_previewWidget, 0, 1, 0, 0);
+    mainLayout->addMultiCellWidget(m_decodingSettingsBox, 0, 0, 1, 1);
     mainLayout->setColStretch(0, 10);
-    mainLayout->setRowStretch(3, 10);
+    mainLayout->setRowStretch(1, 10);
 
     // ---------------------------------------------------------------
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
-                                           I18N_NOOP("A Kipi plugin to convert Raw images\n"
-                                                     "Using KDcraw library"),
+                                           I18N_NOOP("A Kipi plugin to convert a Raw image"),
                                            "(c) 2003-2005, Renchi Raju\n"
-                                           "(c) 2006-2007, Gilles Caulier");
+                                           "(c) 2006-2008, Gilles Caulier");
 
     m_about->addAuthor("Renchi Raju", I18N_NOOP("Original author"),
-                       "renchi@pooh.tam.uiuc.edu");
+                       "renchi at pooh dot tam dot uiuc dot edu");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Maintainer"),
                        "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("RAW Converter Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
@@ -221,8 +192,11 @@ void SingleDialog::readSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    m_decodingSettingsBox->setCameraWB(config.readBoolEntry("Use Camera WB", true));
-    m_decodingSettingsBox->setAutoColorBalance(config.readBoolEntry("Use Auto Color Balance", true));
+    m_decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
+                                            config.readNumEntry("White Balance",
+                                            KDcrawIface::RawDecodingSettings::CAMERA));
+    m_decodingSettingsBox->setCustomWhiteBalance(config.readNumEntry("Custom White Balance", 6500));
+    m_decodingSettingsBox->setCustomWhiteBalanceGreen(config.readDoubleNumEntry("Custom White Balance Green", 1.0));
     m_decodingSettingsBox->setFourColor(config.readBoolEntry("Four Color RGB", false));
     m_decodingSettingsBox->setUnclipColor(config.readNumEntry("Unclip Color", 0));
     m_decodingSettingsBox->setDontStretchPixels(config.readBoolEntry("Dont Stretch Pixels", false));
@@ -231,11 +205,9 @@ void SingleDialog::readSettings()
     m_decodingSettingsBox->setUseBlackPoint(config.readBoolEntry("Use Black Point", false));
     m_decodingSettingsBox->setBlackPoint(config.readNumEntry("Black Point", 0));
     m_decodingSettingsBox->setNRThreshold(config.readNumEntry("NR Threshold", 100));
-    m_decodingSettingsBox->setUseColorMultipliers(config.readBoolEntry("Use Color Multipliers", false));
-    m_decodingSettingsBox->setcolorMultiplier1(config.readDoubleNumEntry("Color Multiplier1", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier2(config.readDoubleNumEntry("Color Multiplier2", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier3(config.readDoubleNumEntry("Color Multiplier3", 1.0));
-    m_decodingSettingsBox->setcolorMultiplier4(config.readDoubleNumEntry("Color Multiplier4", 1.0));
+    m_decodingSettingsBox->setUseCACorrection(config.readBoolEntry("EnableCACorrection", false));
+    m_decodingSettingsBox->setcaRedMultiplier(config.readDoubleNumEntry("caRedMultiplier", 1.0));
+    m_decodingSettingsBox->setcaBlueMultiplier(config.readDoubleNumEntry("caBlueMultiplier", 1.0));
 
     m_decodingSettingsBox->setQuality(
         (KDcrawIface::RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
@@ -261,8 +233,9 @@ void SingleDialog::saveSettings()
     KConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
-    config.writeEntry("Use Camera WB", m_decodingSettingsBox->useCameraWB());
-    config.writeEntry("Use Auto Color Balance", m_decodingSettingsBox->useAutoColorBalance());
+    config.writeEntry("White Balance", m_decodingSettingsBox->whiteBalance());
+    config.writeEntry("Custom White Balance", m_decodingSettingsBox->customWhiteBalance());
+    config.writeEntry("Custom White Balance Green", m_decodingSettingsBox->customWhiteBalanceGreen());
     config.writeEntry("Four Color RGB", m_decodingSettingsBox->useFourColor());
     config.writeEntry("Unclip Color", m_decodingSettingsBox->unclipColor());
     config.writeEntry("Dont Stretch Pixels", m_decodingSettingsBox->useDontStretchPixels());
@@ -271,13 +244,11 @@ void SingleDialog::saveSettings()
     config.writeEntry("Use Black Point", m_decodingSettingsBox->useBlackPoint());
     config.writeEntry("Black Point", m_decodingSettingsBox->blackPoint());
     config.writeEntry("NR Threshold", m_decodingSettingsBox->NRThreshold());
+    config.writeEntry("EnableCACorrection", m_decodingSettingsBox->useCACorrection());
+    config.writeEntry("caRedMultiplier", m_decodingSettingsBox->caRedMultiplier());
+    config.writeEntry("caBlueMultiplier", m_decodingSettingsBox->caBlueMultiplier());
     config.writeEntry("Decoding Quality", (int)m_decodingSettingsBox->quality());
     config.writeEntry("Output Color Space", (int)m_decodingSettingsBox->outputColorSpace());
-    config.writeEntry("Use Color Multipliers", m_decodingSettingsBox->useColorMultipliers());
-    config.writeEntry("Color Multiplier1", m_decodingSettingsBox->colorMultiplier1());
-    config.writeEntry("Color Multiplier2", m_decodingSettingsBox->colorMultiplier2());
-    config.writeEntry("Color Multiplier3", m_decodingSettingsBox->colorMultiplier3());
-    config.writeEntry("Color Multiplier4", m_decodingSettingsBox->colorMultiplier4());
 
     config.writeEntry("Output Format", (int)m_saveSettingsBox->fileFormat());
     config.writeEntry("Conflict", (int)m_saveSettingsBox->conflictRule());
@@ -295,8 +266,9 @@ void SingleDialog::slotHelp()
 void SingleDialog::slotUser1()
 {
     KDcrawIface::RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance         = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance      = m_decodingSettingsBox->useAutoColorBalance();
+    rawDecodingSettings.whiteBalance               = m_decodingSettingsBox->whiteBalance();
+    rawDecodingSettings.customWhiteBalance         = m_decodingSettingsBox->customWhiteBalance();
+    rawDecodingSettings.customWhiteBalanceGreen    = m_decodingSettingsBox->customWhiteBalanceGreen();
     rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
     rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
     rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
@@ -305,13 +277,11 @@ void SingleDialog::slotUser1()
     rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
     rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
     rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
+    rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
+    rawDecodingSettings.caMultiplier[1]            = m_decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
-    rawDecodingSettings.enableColorMultipliers     = m_decodingSettingsBox->useColorMultipliers();
-    rawDecodingSettings.colorBalanceMultipliers[0] = m_decodingSettingsBox->colorMultiplier1();
-    rawDecodingSettings.colorBalanceMultipliers[1] = m_decodingSettingsBox->colorMultiplier2();
-    rawDecodingSettings.colorBalanceMultipliers[2] = m_decodingSettingsBox->colorMultiplier3();
-    rawDecodingSettings.colorBalanceMultipliers[3] = m_decodingSettingsBox->colorMultiplier4();
     
     m_thread->setRawDecodingSettings(rawDecodingSettings, SaveSettingsWidget::OUTPUT_PPM);
     m_thread->processHalfRawFile(KURL(m_inputFile));
@@ -323,8 +293,9 @@ void SingleDialog::slotUser1()
 void SingleDialog::slotUser2()
 {
     KDcrawIface::RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance         = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance      = m_decodingSettingsBox->useAutoColorBalance();
+    rawDecodingSettings.whiteBalance               = m_decodingSettingsBox->whiteBalance();
+    rawDecodingSettings.customWhiteBalance         = m_decodingSettingsBox->customWhiteBalance();
+    rawDecodingSettings.customWhiteBalanceGreen    = m_decodingSettingsBox->customWhiteBalanceGreen();
     rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
     rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
     rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
@@ -333,13 +304,11 @@ void SingleDialog::slotUser2()
     rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
     rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
     rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.enableCACorrection         = m_decodingSettingsBox->useCACorrection();
+    rawDecodingSettings.caMultiplier[0]            = m_decodingSettingsBox->caRedMultiplier();
+    rawDecodingSettings.caMultiplier[1]            = m_decodingSettingsBox->caBlueMultiplier();
     rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
     rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
-    rawDecodingSettings.enableColorMultipliers     = m_decodingSettingsBox->useColorMultipliers();
-    rawDecodingSettings.colorBalanceMultipliers[0] = m_decodingSettingsBox->colorMultiplier1();
-    rawDecodingSettings.colorBalanceMultipliers[1] = m_decodingSettingsBox->colorMultiplier2();
-    rawDecodingSettings.colorBalanceMultipliers[2] = m_decodingSettingsBox->colorMultiplier3();
-    rawDecodingSettings.colorBalanceMultipliers[3] = m_decodingSettingsBox->colorMultiplier4();
 
     m_thread->setRawDecodingSettings(rawDecodingSettings, m_saveSettingsBox->fileFormat());
     m_thread->processRawFile(KURL(m_inputFile));
@@ -362,7 +331,7 @@ void SingleDialog::slotIdentify()
 
 void SingleDialog::busy(bool val)
 {   
-    m_rawSettingsGroup->setEnabled(!val);
+    m_decodingSettingsBox->setEnabled(!val);
     m_saveSettingsBox->setEnabled(!val);
     enableButton (User1, !val);
     enableButton (User2, !val);
