@@ -1,31 +1,34 @@
 /* ============================================================
- * File  : simpleviewerexport.cpp
- * Author: Joern Ahrens <joern.ahrens@kdemail.net>
- * Date  : 2005-12-19
- * Description :
  *
- * Copyright 2005-2006 by Joern Ahrens <joern.ahrens@kdemail.net>
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2005-12-19
+ * Description : a plugin to export image collections using SimpleViewer.
+ *
+ * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
+ * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // QT includes
 
 #include <qtimer.h>
 #include <qimage.h>
-#include <qtextstream.h>
 #include <qfile.h>
 #include <qdir.h>
+#include <qcstring.h>
+#include <qdatastream.h>
 
 // KDE includes
 
@@ -47,24 +50,35 @@
 #include <libkipi/batchprogressdialog.h>
 #include <libkipi/imageinfo.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawbinary.h>
+#include <libkdcraw/kdcraw.h>
+
+// LibKExiv2 includes.
+
+#include <libkexiv2/kexiv2.h>
+
 // Local includes
 
-#include "simpleviewerexport.h"
+#include "pluginsversion.h"
 #include "firstrundlg.h"
 #include "svedialog.h"
+#include "simpleviewerexport.h"
+#include "simpleviewerexport.moc"
 
 namespace KIPISimpleViewerExportPlugin
 {
-    
+
 // maxium size of a simpleviewer thumbnail
 // TODO: read from configfile
 const int maxThumbSize = 45;
 const QString viewer("viewer.swf");
-    
-/* static */ void SimpleViewerExport::run(KIPI::Interface* interface, QObject *parent)
+
+void SimpleViewerExport::run(KIPI::Interface* interface, QObject *parent)
 {
     SimpleViewerExport *plugin = new SimpleViewerExport(interface, parent);
- 
+
     if(!plugin->checkSimpleViewer())
     {
         if(!plugin->installSimpleViewer())
@@ -73,37 +87,35 @@ const QString viewer("viewer.swf");
             return;
         }
     }
-    
+
     if(plugin->configure())
         plugin->startExport();
-    
+
     delete plugin;
 }
-    
+
 SimpleViewerExport::SimpleViewerExport(KIPI::Interface* interface, QObject *parent)
-    : QObject(parent)
+                  : QObject(parent)
 {
-    m_interface = interface;
-    m_configDlg = 0;
+    m_interface    = interface;
+    m_configDlg    = 0;
     m_totalActions = 0;
-    m_action = 0;
-    m_canceled = true;
-    m_dataLocal = locateLocal("data", "kipiplugin_simpleviewerexport/simpleviewer/", true);
-    m_tempDir = 0;
-    
+    m_action       = 0;
+    m_canceled     = true;
+    m_dataLocal    = locateLocal("data", "kipiplugin_simpleviewerexport/simpleviewer/", true);
+    m_tempDir      = 0;
+
     m_simpleViewerFiles.append(viewer);
-    m_simpleViewerFiles.append("flash_detect.js");
-    m_simpleViewerFiles.append("get_flash_player.gif");
-    
+    m_simpleViewerFiles.append("swfobject.js");
+
     const KAboutData *data = KApplication::kApplication()->aboutData();
-    m_hostName = QString::QString( data->appName() );
-       
-    m_hostURL = data->homepage();
-    
+    m_hostName             = QString::QString( data->appName() );
+    m_hostURL              = data->homepage();
+
     if (m_hostURL.isEmpty())
     {
         m_hostName = "Kipi";
-        m_hostURL = "http://extragear.kde.org/apps/kipi";
+        m_hostURL  = "http://www.kipi-plugins.org";
     }
 }
 
@@ -116,7 +128,7 @@ SimpleViewerExport::~SimpleViewerExport()
 bool SimpleViewerExport::configure()
 {
     m_canceled = false;
-    
+
     if(!m_configDlg)
         m_configDlg = new SVEDialog(m_interface, kapp->activeWindow());
 
@@ -125,16 +137,16 @@ bool SimpleViewerExport::configure()
     {
         if(m_configDlg->exec() == QDialog::Rejected)
             return false;
-    
+
         configured = true;
-        
+
         if(KIO::NetAccess::exists(m_configDlg->exportURL(), false, kapp->activeWindow()))
         {
             int ret = KMessageBox::warningYesNoCancel(kapp->activeWindow(),
                                                       i18n("Target folder %1 already exists.\n"
                                                            "Do you want to overwrite it (all data in this folder will be lost)")
                                                            .arg(m_configDlg->exportURL()));
-            
+
             switch(ret)
             {
                 case KMessageBox::Yes:
@@ -145,18 +157,18 @@ bool SimpleViewerExport::configure()
                         configured = false;
                     }
                     break;
-                
+
                 case KMessageBox::No:
                     configured = false;
                     break;
-                
+
                 case KMessageBox::Cancel:
                     return false;
                     break;
             };
         }
     }
-    
+
     return true;
 }
 
@@ -164,16 +176,15 @@ void SimpleViewerExport::startExport()
 {
     if(m_canceled)
         return;
-    
-    m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(),
-                                                  i18n("Simple Viewer Export"));
-        
+
+    m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), i18n("Flash Export"));
+
     connect(m_progressDlg, SIGNAL(cancelClicked()),
             this, SLOT(slotCancel()));
 
     m_progressDlg->show();
     kapp->processEvents();
-    
+
     // Estimate the number of actions for the KIPI progress dialog.
     m_progressDlg->addedAction(i18n("Estimate the number of actions to do..."), KIPI::StartingMessage);
     m_albumsList = m_configDlg->getSelectedAlbums();
@@ -183,10 +194,10 @@ void SimpleViewerExport::startExport()
     {
         m_totalActions += (*it).images().count();
     }
-    
+
     // +copying SimpleViewer, +creating index.html
     m_totalActions += 2;
-    
+
     m_progressDlg->setProgress(0, m_totalActions);
 
     slotProcess();
@@ -209,9 +220,9 @@ void SimpleViewerExport::slotProcess()
 {
     if(m_canceled)
         return;
-    
+
     m_progressDlg->addedAction(i18n("Initialising..."), KIPI::StartingMessage);
-    
+
     if(!m_canceled && !createExportDirectories())
     {
             m_progressDlg->addedAction(i18n("Failed to create export directories"),
@@ -225,12 +236,12 @@ void SimpleViewerExport::slotProcess()
                                    KIPI::ErrorMessage);
         return;
     }
-    
+
     if(!m_canceled && !createIndex())
     {
         m_progressDlg->addedAction(i18n("Failed to create index.html"),
                                    KIPI::ErrorMessage);
-        return;        
+        return;
     }
 
     if(!m_canceled && !copySimpleViewer())
@@ -258,7 +269,7 @@ void SimpleViewerExport::slotProcess()
             KIO::NetAccess::del(m_configDlg->exportURL(), kapp->activeWindow());
         }
     }
-    
+
     if(!m_canceled)
         m_progressDlg->addedAction(i18n("Finished..."), KIPI::SuccessMessage);
 }
@@ -268,8 +279,8 @@ bool SimpleViewerExport::createExportDirectories()
     m_tempDir = new KTempDir(locateLocal("tmp", "simpleviewerexport"));
     m_tempDir->setAutoDelete(true);
 
-    m_progressDlg->addedAction(i18n("Creating directories..."), KIPI::StartingMessage);    
-    
+    m_progressDlg->addedAction(i18n("Creating directories..."), KIPI::StartingMessage);
+
     KURL root = m_configDlg->exportURL();
     if(!KIO::NetAccess::mkdir(root, kapp->activeWindow()))
     {
@@ -277,7 +288,7 @@ bool SimpleViewerExport::createExportDirectories()
                                    KIPI::ErrorMessage);
         return(false);
     }
-  
+
     KURL thumbsDir = m_tempDir->name();
     thumbsDir.addPath("/thumbs");
     if(!KIO::NetAccess::mkdir(thumbsDir, kapp->activeWindow()))
@@ -295,10 +306,10 @@ bool SimpleViewerExport::createExportDirectories()
                                    KIPI::ErrorMessage);
         return(false);
     }
-    
+
     m_progressDlg->setProgress(++m_action, m_totalActions);
     m_progressDlg->addedAction(i18n("Directories created..."), KIPI::SuccessMessage);
-    
+
     return true;
 }
 
@@ -311,70 +322,116 @@ bool SimpleViewerExport::exportImages()
 
     KURL thumbsDir(m_tempDir->name());
     thumbsDir.addPath("/thumbs");
-    
+
     KURL imagesDir(m_tempDir->name());
     imagesDir.addPath("/images");
 
     KURL xmlFile(m_tempDir->name());
-    xmlFile.addPath("/imageData.xml");
+    xmlFile.addPath("/gallery.xml");
     QFile file(xmlFile.path());
     file.open(IO_WriteOnly);
-    QTextStream ts(&file);
-    cfgCreateHeader(ts);
 
-    int maxSize = m_configDlg->imagesExportSize();
+    QDomDocument xmlDoc;
+    xmlDoc.appendChild(xmlDoc.createProcessingInstruction( QString::fromLatin1("xml"),
+                       QString::fromLatin1("version=\"1.0\" encoding=\"UTF-8\"") ) );
+    QDomElement galleryElem = xmlDoc.createElement(QString::fromLatin1("simpleviewerGallery")); 
+    xmlDoc.appendChild( galleryElem );
+    galleryElem.setAttribute(QString::fromLatin1("maxImageWidth"),    m_configDlg->maxImageDimension());
+    galleryElem.setAttribute(QString::fromLatin1("maxImageHeight"),   m_configDlg->maxImageDimension());
+    galleryElem.setAttribute(QString::fromLatin1("textColor"),        m_configDlg->textColor().name().replace("#", "0x"));
+    galleryElem.setAttribute(QString::fromLatin1("frameColor"),       m_configDlg->frameColor().name().replace("#", "0x"));
+    galleryElem.setAttribute(QString::fromLatin1("bgColor"),          m_configDlg->backgroundColor().name().replace("#", "0x"));
+    galleryElem.setAttribute(QString::fromLatin1("frameWidth"),       m_configDlg->frameWidth());
+    galleryElem.setAttribute(QString::fromLatin1("stagePadding"),     m_configDlg->stagePadding());
+    galleryElem.setAttribute(QString::fromLatin1("thumbnailColumns"), m_configDlg->thumbnailColumns());
+    galleryElem.setAttribute(QString::fromLatin1("thumbnailRows"),    m_configDlg->thumbnailRows());
+    galleryElem.setAttribute(QString::fromLatin1("navPosition"),      m_configDlg->navPosition());
+    galleryElem.setAttribute(QString::fromLatin1("navDirection"),     m_configDlg->navDirection());
+    galleryElem.setAttribute(QString::fromLatin1("title"),            m_configDlg->title());
+    galleryElem.setAttribute(QString::fromLatin1("imagePath"),        QString());
+    galleryElem.setAttribute(QString::fromLatin1("thumbPath"),        QString());
+
+    KExiv2Iface::KExiv2 meta;
+    QImage              image;
+    QImage              thumbnail;
+    QString             tmp;
+    QString             newName;
+
+    int index         = 1;
+    int maxSize       = m_configDlg->imagesExportSize();
     bool resizeImages = m_configDlg->resizeExportImages();
+
     for( QValueList<KIPI::ImageCollection>::Iterator it = m_albumsList.begin() ;
          !m_canceled && (it != m_albumsList.end()) ; ++it )
     {
         KURL::List images = (*it).images();
+
         for(KURL::List::Iterator it = images.begin();
             !m_canceled && (it != images.end()) ; ++it)
         {
             kapp->processEvents();
+            KURL url = *it;
+            QFileInfo fileInfo(url.path());
 
-            KURL kurl = *it;
-            m_progressDlg->addedAction(i18n("Processing %1").arg((*it).url()),
-                                       KIPI::StartingMessage);
-            QImage image;
-            if(!image.load(kurl.path()))
+            m_progressDlg->addedAction(i18n("Processing %1").arg(url.filename()), KIPI::StartingMessage);
+
+            // Check if RAW file.
+            QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
+            if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
+                KDcrawIface::KDcraw::loadDcrawPreview(image, url.path());
+            else
+                image.load(url.path());
+
+            if(image.isNull())
             {
-                m_progressDlg->addedAction(i18n("Could not open image '%1'").arg(kurl.path()),
+                m_progressDlg->addedAction(i18n("Could not open image '%1'").arg(url.filename()),
                                            KIPI::WarningMessage);
                 continue;
             }
 
-            QImage thumbnail;
             if(!createThumbnail(image, thumbnail))
             {
-                m_progressDlg->addedAction(i18n("Could not create thumbnail from '%1'").arg(kurl.path()),
+                m_progressDlg->addedAction(i18n("Could not create thumbnail from '%1'").arg(url.filename()),
                                            KIPI::WarningMessage);
                 continue;
             }
 
             if(resizeImages && !resizeImage(image, maxSize, image))
             {
-                m_progressDlg->addedAction(i18n("Could not resize image '%1'").arg(kurl.path()),
+                m_progressDlg->addedAction(i18n("Could not resize image '%1'").arg(url.filename()),
                                            KIPI::WarningMessage);
                 continue;
             }
 
+            meta.load(url.path());
+            newName = QString("%1.%2").arg(tmp.sprintf("%03i", index)).arg(QString("jpg"));
+
             KURL thumbnailPath(thumbsDir);
-            thumbnailPath.addPath(kurl.filename());
+            thumbnailPath.addPath(newName);
             thumbnail.save(thumbnailPath.path(), "JPEG");
 
             KURL imagePath(imagesDir);
-            imagePath.addPath(kurl.filename());
+            imagePath.addPath(newName);
             image.save(imagePath.path(), "JPEG");
 
-            cfgAddImage(ts, kurl);
+            // Backup metadata from original image.
+            meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
+            meta.setImageDimensions(image.size());
+            meta.save(imagePath.path());
+
+            cfgAddImage(xmlDoc, galleryElem, url, newName);
             m_progressDlg->setProgress(++m_action, m_totalActions);
+            index++;
         }
-        cfgCreateFooter(ts);
     }
-    
-    m_progressDlg->addedAction(i18n("Images and thumbnails created..."), KIPI::SuccessMessage);    
-    
+
+    QCString data(xmlDoc.toCString());
+    QDataStream stream( &file );
+    stream.writeRawBytes(data.data(), data.size());
+    file.close();
+
+    m_progressDlg->addedAction(i18n("Images and thumbnails created..."), KIPI::SuccessMessage);
+
     return true;
 }
 
@@ -396,9 +453,9 @@ bool SimpleViewerExport::createThumbnail(const QImage &image, QImage &thumbnail)
             maxSize = (int)(double)(h * maxThumbSize) / w;
         }
     }
-    
+
     maxSize = (maxSize < maxThumbSize) ? maxThumbSize : maxSize;
-    
+
     return resizeImage(image, maxSize, thumbnail);
 }
 
@@ -427,28 +484,8 @@ bool SimpleViewerExport::resizeImage(const QImage &image, int maxSize, QImage &r
     return true;
 }
 
-void SimpleViewerExport::cfgCreateHeader(QTextStream &ts)
-{
-    if(m_canceled)
-        return;
-
-    ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
-    ts << "<SIMPLEVIEWER_DATA"
-       << " maxImageDimension=\""   << m_configDlg->maxImageDimension() << "\""
-       << " textColor=\""           << m_configDlg->textColor().name().replace("#", "0x") << "\""
-       << " frameColor=\""          << m_configDlg->frameColor().name().replace("#", "0x") << "\""
-       << " bgColor=\""             << m_configDlg->backgroundColor().name().replace("#", "0x") << "\""
-       << " frameWidth=\""          << m_configDlg->frameWidth() << "\""
-       << " stagePadding=\""        << m_configDlg->stagePadding() << "\""
-       << " thumbnailColumns=\""    << m_configDlg->thumbnailColumns() << "\""
-       << " thumbnailRows=\""       << m_configDlg->thumbnailRows() << "\""
-       << " navPosition=\""         << m_configDlg->navPosition() << "\""
-       << " navDirection=\""        << m_configDlg->navDirection() << "\""
-       << " title=\""               << m_configDlg->title() << "\""
-       << " imagePath=\"\" thumbPath=\"\">" << endl;
-}
-
-void SimpleViewerExport::cfgAddImage(QTextStream &ts, const KURL &kurl)
+void SimpleViewerExport::cfgAddImage(QDomDocument &xmlDoc, QDomElement &galleryElem, 
+                                     const KURL &url, const QString& newName)
 {
     if(m_canceled)
         return;
@@ -457,33 +494,33 @@ void SimpleViewerExport::cfgAddImage(QTextStream &ts, const KURL &kurl)
 
     if(m_configDlg->showExifComments())
     {
-        KIPI::ImageInfo info = m_interface->info(kurl);
+        KIPI::ImageInfo info = m_interface->info(url);
         comment = info.description();
     }
     else
     {
-        comment = "";
+        comment = QString();
     }
 
-    ts << "<IMAGE>" << endl;
-    ts << "<NAME>" << kurl.filename() << "</NAME>" << endl;
-    ts << "<CAPTION>" <<  comment  <<  "</CAPTION>" << endl;
-    ts << "</IMAGE>" << endl;
-}
+    QDomElement img = xmlDoc.createElement(QString::fromLatin1("image")); 
+    galleryElem.appendChild(img);
 
-void SimpleViewerExport::cfgCreateFooter(QTextStream &ts)
-{
-    if(m_canceled)
-        return;
-    
-    ts << "</SIMPLEVIEWER_DATA>" << endl;
+    QDomElement name = xmlDoc.createElement(QString::fromLatin1("name")); 
+    img.appendChild(name);
+    QDomText nametxt = xmlDoc.createTextNode(newName);
+    name.appendChild(nametxt);
+
+    QDomElement caption = xmlDoc.createElement(QString::fromLatin1("caption")); 
+    img.appendChild(caption);
+    QDomText captiontxt = xmlDoc.createTextNode(comment);
+    caption.appendChild(captiontxt);
 }
 
 bool SimpleViewerExport::createIndex()
 {
     if(m_canceled)
         return false;
-    
+
     m_progressDlg->addedAction(i18n("Creating index.html..."), KIPI::StartingMessage);
 
     QString indexTemplateName = locate("data", "kipiplugin_simpleviewerexport/index.template");
@@ -493,28 +530,28 @@ bool SimpleViewerExport::createIndex()
         kdDebug() << "No indexTemplateName" << endl;
         return false;
     }
-    
+
     QFile infile(indexTemplateName);
     infile.open(IO_ReadOnly);
     QTextStream in(&infile);
     QString indexTemplate = in.read();
     infile.close();
-    
+
     indexTemplate.replace("{TITLE}", m_configDlg->title());
     indexTemplate.replace("{COLOR}", m_configDlg->textColor().name());
     indexTemplate.replace("{BGCOLOR}", m_configDlg->backgroundColor().name());
     indexTemplate.replace("{HOSTURL}", m_hostURL);
     indexTemplate.replace("{HOSTNAME}", m_hostName);
-    
+
     QFile outfile(m_tempDir->name() + "/index.html");
     outfile.open(IO_WriteOnly);
     QTextStream out(&outfile);
     out << indexTemplate;
     outfile.close();
-    
+
     m_progressDlg->setProgress(++m_action, m_totalActions);
     m_progressDlg->addedAction(i18n("index.html created..."), KIPI::SuccessMessage);
-    
+
     return true;
 }
 
@@ -526,25 +563,25 @@ bool SimpleViewerExport::copySimpleViewer()
     m_progressDlg->addedAction(i18n("Copying flash files..."), KIPI::StartingMessage);
 
     QString dataDir;
-    
+
     // Due to its license, simpleviewer is installed in $KDEHOME
     dataDir = locate("data", "kipiplugin_simpleviewerexport/simpleviewer/");
     if(dataDir.isEmpty())
         installSimpleViewer();
     if(dataDir.isEmpty())
         return false;
-   
+
     QStringList files;
     QStringList entries;
     QDir dir;
-    
+
     dir.setPath(dataDir);
     entries = dir.entryList(QDir::Files);
     for(QStringList::Iterator it = entries.begin(); it != entries.end(); ++it) 
     {
         files.append(dir.absPath() + "/" + *it);
     }
-    
+
     // files distributed with the plugin are installed in $KDEDIRS
     dataDir = locate("data", "kipiplugin_simpleviewerexport/simpleviewer_html/");
     dir.setPath(dataDir);
@@ -555,7 +592,7 @@ bool SimpleViewerExport::copySimpleViewer()
     }
     // TODO: catch errors
     KIO::CopyJob *copyJob = KIO::copy(files, m_configDlg->exportURL(), true);
-    
+
     m_progressDlg->addedAction(i18n("flash files copied..."), KIPI::SuccessMessage);
 
     return true;
@@ -568,11 +605,11 @@ bool SimpleViewerExport::upload()
 
     m_progressDlg->addedAction(i18n("Uploading gallery..."), KIPI::StartingMessage);
 
-    if(!KIO::NetAccess::dircopy(m_tempDir->name() + "./", m_configDlg->exportURL()))
+    if(!KIO::NetAccess::dircopy(m_tempDir->name() + "./", m_configDlg->exportURL(), 0))
         return false;
 
     m_progressDlg->addedAction(i18n("Gallery uploaded..."), KIPI::SuccessMessage);
-    
+
     return true;
 }
 
@@ -588,7 +625,7 @@ bool SimpleViewerExport::installSimpleViewer()
     {
         QString url = firstRunDlg->getURL();
         delete firstRunDlg;
-        
+
         if(unzip(url))
         {
             return true;
@@ -598,19 +635,19 @@ bool SimpleViewerExport::installSimpleViewer()
             // ErrorMessage
         }
     }
-    
+
     return false;
 }
 
 bool SimpleViewerExport::unzip(const QString &url)
 {
     KZip zip(url);
-    
-    if(!openArchive(zip))    
+
+    if(!openArchive(zip))
     {
         return false;
     }
-    
+
     return extractArchive(zip);
 }
 
@@ -634,7 +671,7 @@ bool SimpleViewerExport::extractArchive(KZip &zip)
         kdDebug() << "Content of the archive root folder" << names << endl;
         return false;
     }
-            
+
     // open root directory
     const KArchiveEntry *root = zip.directory()->entry(names[0]);
     if(!root || !root->isDirectory())
@@ -642,9 +679,9 @@ bool SimpleViewerExport::extractArchive(KZip &zip)
         kdDebug() << "could not open " << names[0] << " of zipname" << endl;
         return false;
     }
-    
+
     const KArchiveDirectory *dir = dynamic_cast<const KArchiveDirectory*>(root);
-            
+
     // extract the needed files from SimpleViewer archive
     for(QStringList::Iterator it = m_simpleViewerFiles.begin(); 
         it != m_simpleViewerFiles.end(); ++it ) 
@@ -657,7 +694,7 @@ bool SimpleViewerExport::extractArchive(KZip &zip)
             return false;
         }
     }
-    
+
     return true;
 }
 
@@ -665,7 +702,7 @@ bool SimpleViewerExport::extractFile(const KArchiveEntry *entry)
 {
     if( !entry || !entry->isFile() ) 
         return false;
-   
+
     const KArchiveFile *entryFile = dynamic_cast<const KArchiveFile*>(entry);
     QByteArray array = entryFile->data();
 
@@ -676,10 +713,8 @@ bool SimpleViewerExport::extractFile(const KArchiveEntry *entry)
         file.close();
         return ret > 0 ? true : false;
     }
-    
+
     return false;
 }
 
 } // namespace KIPISimpleViewerExportPlugin
-
-#include "simpleviewerexport.moc"
