@@ -1,22 +1,24 @@
 /* ============================================================
- * File  : svedialog.h
- * Author: Joern Ahrens <joern.ahrens@kdemail.net>
- * Date  : 2005-12-19
- * Description :
  *
- * Copyright 2005-2006 by Joern Ahrens <joern.ahrens@kdemail.net>
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2005-12-19
+ * Description : a plugin to export image collections using SimpleViewer.
+ *
+ * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
+ * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // QT include files
@@ -25,7 +27,6 @@
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qlineedit.h>
 #include <qlayout.h>
 #include <qwhatsthis.h>
 #include <qcheckbox.h>
@@ -37,6 +38,7 @@
 
 // KDE include files
 
+#include <klineedit.h>
 #include <klocale.h>
 #include <khelpmenu.h>
 #include <kpopupmenu.h>
@@ -47,6 +49,7 @@
 #include <kurlrequester.h>
 #include <kglobalsettings.h>
 #include <kconfig.h>
+#include <kapplication.h>
 
 // KIPI include files
 
@@ -63,47 +66,48 @@ namespace KIPISimpleViewerExportPlugin
 {
 
 SVEDialog::SVEDialog(KIPI::Interface* interface, QWidget *parent)
-          : KDialogBase( IconList, i18n("Configure"), Help|Ok|Cancel, Ok,
+          : KDialogBase( IconList, i18n("Flash Export"), Help|Ok|Cancel, Ok,
                          parent, "SimpleViewerExportDialog", true, true ),
             m_interface( interface )
 {
-    setCaption(i18n("Simple Viewer Export"));
-
     selectionPage();
     generalPage();
     lookPage();
 
     readConfig();
 
-    resize( 650, 450 );
-
     // About data and help button.
 
-    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Simple Viewer"),
-                                           NULL,
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Flash Export"),
+                                           0,
                                            KAboutData::License_GPL,
-                                           I18N_NOOP("A Kipi plugin for Simple Viewer export."),
-                                           "(c) 2005-2006, Joern Ahrens");
+                                           I18N_NOOP("A Kipi plugin to export images to Flash using Simple Viewer component"),
+                                           "(c) 2005-2006, Joern Ahrens\n"
+                                           "(c) 2008, Gilles Caulier");
 
     m_about->addAuthor("Joern Ahrens", 
                        I18N_NOOP("Author and maintainer"),
                        "joern dot ahrens at kdemail dot net");
-    
+
+    m_about->addAuthor("Gilles Caulier", 
+                       I18N_NOOP("Developer and maintainer"),
+                       "caulier dot gilles at gmail dot com");
+
     m_about->addCredit("Felix Turner",
-                       "Author of the SimpleViewer flash application",
+                       "Author of the Simple Viewer Flash component",
                        0,
-                       "http://www.airtightinteractive.com/simpleviewer/");
-    
+                       "http://www.airtightinteractive.com/simpleviewer");
+
     m_about->addCredit("Mikkel B. Stegmann",
                        "Basis for the index.html template",
                        0,
-                       "http://www.stegmann.dk/mikkel/porta/");
+                       "http://www.stegmann.dk/mikkel/porta");
 
-    QPushButton *helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-//    helpMenu->menu()->insertItem(i18n("Image Gallery Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-    helpButton->setPopup( helpMenu->menu() );
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
+                                 this, SLOT(slotHelp()), 0, -1, 0);
+    actionButton(Help)->setPopup( helpMenu->menu() );
 }
 
 SVEDialog::~SVEDialog()
@@ -111,52 +115,55 @@ SVEDialog::~SVEDialog()
     delete m_about;
 }
 
+void SVEDialog::slotHelp()
+{
+    KApplication::kApplication()->invokeHelp("simpleviewerexport", "kipi-plugins");
+}
+
 void SVEDialog::readConfig()
 {
-    KConfig *config = new KConfig("kipisimpleviewerexportrc");
-    
-    setThumbnailRows(config->readNumEntry("thumbnailRows", 1));
-    setThumbnailColumns(config->readNumEntry("thumbnailColumns", 1));
-    m_navPosition->setCurrentItem(config->readNumEntry("navPosition", 1));
-    m_navDirection->setCurrentItem(config->readNumEntry("navDirection", 1));
-    setTextColor(QColor(config->readEntry("textColor", "#ffffff")));
-    setBackgroundColor(QColor(config->readEntry("backgroundColor", "#181818")));    
-    setFrameColor(QColor(config->readEntry("frameColor", "#ffffff")));    
-    setFrameWidth(config->readNumEntry("frameWidth", 1));
-    setStagePadding(config->readNumEntry("stagePadding", 1));
-    setTitle(config->readEntry("title", ""));
-    m_exportURL->setURL(config->readPathEntry("exporturl",  KGlobalSettings::documentPath() + "simpleviewer"));
-    setResizeExportImages(config->readBoolEntry("resizeExportImages", true));
-    setImagesExportSize(config->readNumEntry("imagesExportSize", 640));
-    setMaxImagesDimension(config->readNumEntry("maxImageDimension", 640));
-    setShowExifComments(config->readBoolEntry("showExifComments", true));    
-        
-    delete config;
+    KConfig config("kipirc");
+
+    setThumbnailRows(config.readNumEntry("thumbnailRows", 3));
+    setThumbnailColumns(config.readNumEntry("thumbnailColumns", 3));
+    m_navPosition->setCurrentItem(config.readNumEntry("navPosition", 1));
+    m_navDirection->setCurrentItem(config.readNumEntry("navDirection", 1));
+    setTextColor(QColor(config.readEntry("textColor", "#ffffff")));
+    setBackgroundColor(QColor(config.readEntry("backgroundColor", "#181818")));
+    setFrameColor(QColor(config.readEntry("frameColor", "#ffffff")));
+    setFrameWidth(config.readNumEntry("frameWidth", 1));
+    setStagePadding(config.readNumEntry("stagePadding", 20));
+    setTitle(config.readEntry("title", QString()));
+    m_exportURL->setURL(config.readPathEntry("exporturl",  KGlobalSettings::documentPath() + "simpleviewer"));
+    setResizeExportImages(config.readBoolEntry("resizeExportImages", true));
+    setImagesExportSize(config.readNumEntry("imagesExportSize", 640));
+    setMaxImagesDimension(config.readNumEntry("maxImageDimension", 640));
+    setShowExifComments(config.readBoolEntry("showExifComments", true));
+
+    resize(configDialogSize(config, QString("SimpleViewerExport Dialog")));
 }
 
 void SVEDialog::writeConfig()
 {
-    KConfig *config = new KConfig("kipisimpleviewerexportrc");
-    
-    config->writeEntry("thumbnailRows", thumbnailRows());
-    config->writeEntry("thumbnailColumns", thumbnailColumns());
-    config->writeEntry("navPosition", m_navPosition->currentItem());
-    config->writeEntry("navDirection", m_navDirection->currentItem());
-    config->writeEntry("textColor", textColor().name());
-    config->writeEntry("backgroundColor", backgroundColor().name());    
-    config->writeEntry("frameColor", frameColor().name());
-    config->writeEntry("frameWidth", frameWidth());
-    config->writeEntry("stagePadding", stagePadding());            
-    config->writePathEntry("exporturl", exportURL());
-    config->writeEntry("title", title());
-    config->writeEntry("resizeExportImages", resizeExportImages());
-    config->writeEntry("imagesExportSize", imagesExportSize());
-    config->writeEntry("maxImageDimension", maxImageDimension());
-    config->writeEntry("showExifComments", showExifComments());
-    
-    config->sync(); 
-    
-    delete config;
+    KConfig config("kipirc");
+    config.writeEntry("thumbnailRows", thumbnailRows());
+    config.writeEntry("thumbnailColumns", thumbnailColumns());
+    config.writeEntry("navPosition", m_navPosition->currentItem());
+    config.writeEntry("navDirection", m_navDirection->currentItem());
+    config.writeEntry("textColor", textColor().name());
+    config.writeEntry("backgroundColor", backgroundColor().name());
+    config.writeEntry("frameColor", frameColor().name());
+    config.writeEntry("frameWidth", frameWidth());
+    config.writeEntry("stagePadding", stagePadding());
+    config.writePathEntry("exporturl", exportURL());
+    config.writeEntry("title", title());
+    config.writeEntry("resizeExportImages", resizeExportImages());
+    config.writeEntry("imagesExportSize", imagesExportSize());
+    config.writeEntry("maxImageDimension", maxImageDimension());
+    config.writeEntry("showExifComments", showExifComments());
+
+    saveDialogSize(config, QString("GPS Sync Dialog"));
+    config.sync();
 }
 
 void SVEDialog::selectionPage()
@@ -164,7 +171,7 @@ void SVEDialog::selectionPage()
     m_selectionPage = addPage(i18n("Selection"), i18n("Album Selection"),
                               BarIcon("folder_image", KIcon::SizeMedium));
 
-    QVBoxLayout *layout = new QVBoxLayout( m_selectionPage, 0, spacingHint() );
+    QVBoxLayout *layout       = new QVBoxLayout( m_selectionPage, 0, spacingHint() );
     m_imageCollectionSelector = new KIPI::ImageCollectionSelector( m_selectionPage, m_interface );
     layout->addWidget(m_imageCollectionSelector);
 }
@@ -172,53 +179,44 @@ void SVEDialog::selectionPage()
 void SVEDialog::lookPage()
 {
     m_lookPage = addPage(i18n("Look"), i18n("Page Look"),
-                              BarIcon("html", KIcon::SizeMedium));
+                              BarIcon("colors", KIcon::SizeMedium));
 
     QVBoxLayout *mainLayout = new QVBoxLayout(m_lookPage, 0, spacingHint());
     QVGroupBox *vgroupbox;
     QHBox *hbox;
     QLabel *label;
 
-    // ========================================================================
-    // Navigation
-    // ========================================================================
+    // ------------------------------------------------------------------------
+
     vgroupbox = new QVGroupBox(i18n("Navigation"), m_lookPage);
     mainLayout->addWidget(vgroupbox);
 
-    // ------------------------------------------------------------------------
-    // Number of rows of thumbnails
-    // ------------------------------------------------------------------------
     m_thumbnailRows = new KIntNumInput(3, vgroupbox);
     m_thumbnailRows->setRange(1, 10, 1, true);
     m_thumbnailRows->setLabel(i18n("Thumbnail &Rows:"), AlignVCenter);
-    QWhatsThis::add(m_thumbnailRows, i18n("<p>Number of rows of thumbnails"));
+    QWhatsThis::add(m_thumbnailRows, i18n("<p>Number of thumbnails rows"));
 
     // ------------------------------------------------------------------------
-    // Number of columns of thumbnails
-    // ------------------------------------------------------------------------
-    m_thumbnailColumns = new KIntNumInput(m_thumbnailRows, 3, vgroupbox);
+
+    m_thumbnailColumns = new KIntNumInput(3, vgroupbox);
     m_thumbnailColumns->setRange(1, 10, 1, true);
     m_thumbnailColumns->setLabel(i18n("Thumbnail &Columns:"), AlignVCenter);
-    QWhatsThis::add(m_thumbnailColumns, i18n("<p>Number of columns of thumbnails"));
+    QWhatsThis::add(m_thumbnailColumns, i18n("<p>Number of thumbnails columns"));
 
     // ------------------------------------------------------------------------
-    // navPosition: Position of thumbnails relative to image. Can be "top",
-    //              "bottom","left" or "right".
-    // ------------------------------------------------------------------------
+
     hbox  = new QHBox(vgroupbox);
     label = new QLabel(i18n("Thumbnail &Position:"), hbox);
     m_navPosition = new QComboBox(false, hbox);
     m_navPosition->insertItem(i18n("Right"));
-    m_navPosition->insertItem(i18n("Left"));    
+    m_navPosition->insertItem(i18n("Left"));
     m_navPosition->insertItem(i18n("Top"));
-    m_navPosition->insertItem(i18n("Bottom"));    
+    m_navPosition->insertItem(i18n("Bottom"));
     m_navPosition->setCurrentText(i18n("Right"));
     label->setBuddy(m_navPosition);
 
     // ------------------------------------------------------------------------
-    // navDirection: Direction of navigation. Can be "LTR" (Left to Right)
-    //               or "RTL" (Right to Left)
-    // ------------------------------------------------------------------------
+
     hbox  = new QHBox(vgroupbox);
     label = new QLabel(i18n("&Direction of Navigation:"), hbox);
     m_navDirection = new QComboBox(false, hbox);
@@ -227,60 +225,47 @@ void SVEDialog::lookPage()
     m_navDirection->setCurrentText(i18n("Left to Right"));
     label->setBuddy(m_navDirection);
 
-    // ========================================================================
-    // Colors
-    // ========================================================================
+    // ------------------------------------------------------------------------
+
     vgroupbox = new QVGroupBox(i18n("Colors"), m_lookPage);
     mainLayout->addWidget(vgroupbox);
 
-    // ------------------------------------------------------------------------
-    // textColor: Color of title and caption text
-    // ------------------------------------------------------------------------
     hbox  = new QHBox(vgroupbox);
     label = new QLabel(i18n("&Text Color:"), hbox);
     m_textColor = new KColorButton(QColor("#ffffff"), hbox);
     label->setBuddy(m_textColor);
 
     // ------------------------------------------------------------------------
-    // bgColor: Color of background.
-    // ------------------------------------------------------------------------
+
     hbox  = new QHBox(vgroupbox);
     label = new QLabel(i18n("&Background Color:"), hbox);
     m_backgroundColor = new KColorButton(QColor("#181818"), hbox);
     label->setBuddy(m_backgroundColor);
 
     // ------------------------------------------------------------------------
-    // frameColor: Color of image frame, viewed icon, load bars, thumbnail
-    //             arrows
-    // ------------------------------------------------------------------------
+
     hbox  = new QHBox(vgroupbox);
     label = new QLabel(i18n("&Frame Color:"), hbox);
     m_frameColor = new KColorButton(QColor("#ffffff"), hbox);
     label->setBuddy(m_frameColor);
 
-    // ========================================================================
-    // Style
-    // ========================================================================
+    // ------------------------------------------------------------------------
+
     vgroupbox = new QVGroupBox(i18n("Style"), m_lookPage);
     mainLayout->addWidget(vgroupbox);
-    
-    // ------------------------------------------------------------------------
-    // frameWidth: Width of image frame in pixels.
-    // ------------------------------------------------------------------------
-    m_frameWidth = new KIntNumInput(m_thumbnailRows, 3, vgroupbox);
+
+    m_frameWidth = new KIntNumInput(3, vgroupbox);
     m_frameWidth->setRange(0, 10, 1, true);
     m_frameWidth->setLabel(i18n("Frame &Width:"), AlignVCenter);
     QWhatsThis::add(m_frameWidth, i18n("<p>Width of image frame in pixels."));
 
     // ------------------------------------------------------------------------
-    // stagePadding: Distance between image and thumbnails in pixels.
-    // ------------------------------------------------------------------------
-    m_stagePadding = new KIntNumInput(m_thumbnailRows, 40, vgroupbox);
+
+    m_stagePadding = new KIntNumInput(20, vgroupbox);
     m_stagePadding->setRange(1, 100, 1, true);
     m_stagePadding->setLabel(i18n("Stage &Padding:"), AlignVCenter);
-    QWhatsThis::add(m_stagePadding,
-                    i18n("<p>tagePadding: Distance between image and thumbnails in pixels."));
-    
+    QWhatsThis::add(m_stagePadding, i18n("<p>Stage Padding: Distance between image and thumbnails in pixels."));
+
     mainLayout->addStretch(1);
 }
 
@@ -293,28 +278,24 @@ void SVEDialog::generalPage()
 
     QHGroupBox *hgroupbox;
     QVGroupBox *vgroupbox;
-    
+
     // ------------------------------------------------------------------------
-    // title: title of the Image Gallery
-    // ------------------------------------------------------------------------    
+
     hgroupbox = new QHGroupBox(i18n("Gallery &Title"), m_generalPage);
     mainLayout->addWidget(hgroupbox);
-    
-    m_title = new QLineEdit("", hgroupbox);
-    QWhatsThis::add(m_title, i18n("<p>Enter here the title of the gallery"));
-    mainLayout->addWidget(m_title);
 
-    // ========================================================================
-    // Save to
-    // ========================================================================    
-    vgroupbox = new QVGroupBox(i18n("Save Gallery To"), m_generalPage);
+    m_title   = new KLineEdit(hgroupbox);
+    QWhatsThis::add(m_title, i18n("<p>Enter here the gallery title"));
+
+    // ------------------------------------------------------------------------
+
+    vgroupbox   = new QVGroupBox(i18n("Save Gallery To"), m_generalPage);
     mainLayout->addWidget(vgroupbox);
     m_exportURL = new KURLRequester(KGlobalSettings::documentPath() + "simpleviewer", vgroupbox);
-    m_exportURL->setMode(KFile::Directory | KFile::LocalOnly/* | KFile::ExistingOnly*/);
+    m_exportURL->setMode(KFile::Directory | KFile::LocalOnly);
 
     // ------------------------------------------------------------------------
-    // resize images before export
-    // ------------------------------------------------------------------------
+
     vgroupbox = new QVGroupBox(i18n("Image Size"), m_generalPage);
     mainLayout->addWidget(vgroupbox);
 
@@ -326,35 +307,30 @@ void SVEDialog::generalPage()
     m_imagesExportSize = new KIntNumInput(640, vgroupbox);
     m_imagesExportSize->setRange(200, 2000, 1, true );
     m_imagesExportSize->setLabel(i18n("&Target Images Size:"), AlignVCenter);
-    QWhatsThis::add(m_imagesExportSize, i18n("<p>The new size of the exported images in pixels"
-                                             "SimpleViewer resizes the images as well, but this"
+    QWhatsThis::add(m_imagesExportSize, i18n("<p>The new size of the exported images in pixels. "
+                                             "SimpleViewer resizes the images as well, but this "
                                              "resizes your images before they are uploaded to your server"));
     connect(m_resizeExportImages, SIGNAL(toggled(bool)),
             m_imagesExportSize, SLOT(setEnabled(bool)));
 
     // ------------------------------------------------------------------------
-    // maxImageDimension: largest height or width of your largest image (in pixels).
-    // Images will not be scaled up above this size, to ensure best image quality.
-    // ------------------------------------------------------------------------
+
     m_maxImageDimension = new KIntNumInput(m_imagesExportSize, 640, vgroupbox);
     m_maxImageDimension->setRange(200, 2000, 1, true );
-    m_maxImageDimension->setLabel(i18n("&SimpleViewer Images Size:"), AlignVCenter);
-    QWhatsThis::add(m_maxImageDimension, i18n("<p>SimpleViewer scales the images to this size"));
-    
-    // ========================================================================
-    // Misc
-    // ========================================================================    
+    m_maxImageDimension->setLabel(i18n("&Displayed Images Size:"), AlignVCenter);
+    QWhatsThis::add(m_maxImageDimension, i18n("<p>scales the displayed images to this size. "
+                                              "Largest height or width of your largest image (in pixels). "
+                                              "Images will not be scaled up above this size, to ensure best image quality."));
+
+    // ------------------------------------------------------------------------
+
     vgroupbox = new QVGroupBox(i18n("Misc"), m_generalPage);
     mainLayout->addWidget(vgroupbox);
-    
-    // ------------------------------------------------------------------------
-    // show EXIF comments
-    // ------------------------------------------------------------------------
-    m_showExifComments = new QCheckBox(i18n("Display EXIF Comments"), vgroupbox);
+
+    m_showExifComments = new QCheckBox(i18n("Display Captions"), vgroupbox);
     m_showExifComments->setChecked(true);
-    mainLayout->addWidget(m_showExifComments);
     QWhatsThis::add(m_showExifComments, i18n("<p>If you enable this option, "
-                                             "the EXIF comments of the images will be shown"));
+                                             "the images caption will be shown"));
 
     mainLayout->addStretch(1);
 }
@@ -457,7 +433,7 @@ int SVEDialog::frameWidth() const
 {
     return m_frameWidth->value();
 }
-        
+
 void SVEDialog::setFrameWidth(int width)
 {
     m_frameWidth->setValue(width);
@@ -529,8 +505,8 @@ QString SVEDialog::navPosition() const
         return "bottom";
     else if(pos == i18n("Left"))
         return "left";
-    else //if(direction == i18n("Right"))
-        return "right";   
+    else
+        return "right";
 }
 
 void SVEDialog::setNavPosition(const QString &pos)
@@ -539,4 +515,3 @@ void SVEDialog::setNavPosition(const QString &pos)
 }
 
 } //  namespace KIPISimpleViewerExportPlugin
-
