@@ -1,20 +1,22 @@
 /* ============================================================
- * File  : slideshowconfig.cpp
- * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Date  : 2003-02-17
- * Description : KIPI slideshow plugin.
  *
- * Copyright 2003-2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-02-17
+ * Description : a kipi plugin to slide images.
+ *
+ * Copyright (C) 2006-2007 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -58,16 +60,14 @@
 #include <libkipi/interface.h>
 #include <libkipi/imagedialog.h>
 
-// Common includes.
+// Local includes.
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-
-// Local includes
-
 #include "listimageitems.h"
 #include "slideshow.h"
 #include "slideshowgl.h"
+#include "slideshowkb.h"
 #include "slideshowconfig.h"
 #include "slideshowconfig.moc"
 
@@ -77,26 +77,25 @@ namespace KIPISlideShowPlugin
 SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * interface, 
                                  QWidget *parent, const char* name, bool ImagesHasComments,
                                  KURL::List *urlList)
-    :SlideShowConfigBase(parent, name) 
+               : SlideShowConfigBase(parent, name) 
 {
     // About data and help button.
 
     KIPIPlugins::KPAboutData * about = new KIPIPlugins::KPAboutData(I18N_NOOP("Slide Show"),
-                                        NULL,
+                                        0,
                                         KAboutData::License_GPL,
                                         I18N_NOOP("A Kipi plugin for image slideshow"),
-                                        "(c) 2003-2004, Renchi Raju");
+                                        "(c) 2003-2004, Renchi Raju\n(c) 2007, Valerio Fuoglio");
 
     about->addAuthor("Renchi Raju", I18N_NOOP("Author"),
                      "renchi@pooh.tam.uiuc.edu");
-    about->addAuthor("Valerio Fuoglio", I18N_NOOP("Maintainer"),
-                     "valerio@ulteo.com");
-
-     KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
-     helpMenu->menu()->removeItemAt(0);
-     helpMenu->menu()->insertItem(i18n("SlideShow Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-     m_helpButton->setPopup( helpMenu->menu() );
+    about->addAuthor("Valerio Fuoglio", I18N_NOOP("Author and maintainer"),
+                     "valerio.fuoglio@gmail.com");
 
+    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+    helpMenu->menu()->removeItemAt(0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    m_helpButton->setPopup( helpMenu->menu() );
 
     // Switch to selected files only (it depends on allowSelectedOnly)
 
@@ -121,6 +120,7 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
     connect(m_commentsBgColor, SIGNAL(changed(const QColor &)), this, SLOT(slotCommentsBgColorChanged()));
     connect(m_useMillisecondsCheckBox, SIGNAL(toggled(bool)), SLOT(slotUseMillisecondsToggled()));
     connect(m_delaySpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotDelayChanged()));
+    connect(m_effectsComboBox, SIGNAL(activated(int)), this,  SLOT(slotEffectChanged()));
 
     connect(m_fileSrcButtonGroup, SIGNAL(clicked(int)), this, SLOT(slotSelection()));
 
@@ -137,6 +137,8 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
     connect( m_ImagesFilesButtonDown, SIGNAL( clicked() ),
              this, SLOT( slotImagesFilesButtonDown() ) );
     
+    connect(m_cacheCheckBox, SIGNAL(toggled(bool)), this, SLOT(slotCacheToggled()));
+    
     m_thumbJob = 0L;
     
     // Configuration file management 
@@ -162,16 +164,15 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
     m_urlList = urlList;
     
     slotSelection();
+    slotEffectChanged();
 }
 
-
 SlideShowConfig::~SlideShowConfig()
 {
     if ( m_thumbJob )   delete m_thumbJob;
     if ( m_config )     delete m_config;
 }
 
-
 void SlideShowConfig::loadEffectNames()
 {
     m_effectsComboBox->clear();
@@ -193,25 +194,35 @@ void SlideShowConfig::loadEffectNames()
     }
 }
 
-
 void SlideShowConfig::loadEffectNamesGL()
 {
     m_effectsComboBox->clear();
 
-    QMap<QString,QString> effectNames = SlideShowGL::effectNamesI18N();
     QStringList effects;
-
+    QMap<QString,QString> effectNames;
     QMap<QString,QString>::Iterator it;
+    
+    // Load slideshowgl effects
+    effectNames = SlideShowGL::effectNamesI18N();
+
     for (it = effectNames.begin(); it != effectNames.end(); ++it)
         effects.append(it.data());
 
+    // Load Ken Burns effect
+    effectNames = SlideShowKB::effectNamesI18N();
+    for (it = effectNames.begin(); it != effectNames.end(); ++it)
+      effects.append(it.data());
+
+    // Update GUI
+    
+   effects.sort();
     m_effectsComboBox->insertStringList(effects);
 
     for (int i=0; i<m_effectsComboBox->count(); i++) {
-        if (effectNames[m_effectNameGL] == m_effectsComboBox->text(i)) {
-            m_effectsComboBox->setCurrentItem(i);
-            break;
-        }
+      if (effectNames[m_effectNameGL] == m_effectsComboBox->text(i)) {
+        m_effectsComboBox->setCurrentItem(i);
+        break;
+      }
     }
 }
 
@@ -229,8 +240,6 @@ void SlideShowConfig::readSettings()
     bool  useMilliseconds;
     bool  enableMouseWheel;
     
-
-
     opengl                = m_config->readBoolEntry("OpenGL", false);
     delay                 = m_config->readNumEntry("Delay", 1500);
     printFileName         = m_config->readBoolEntry("Print Filename", true);
@@ -245,6 +254,7 @@ void SlideShowConfig::readSettings()
     useMilliseconds       = m_config->readBoolEntry("Use Milliseconds", false);
     enableMouseWheel      = m_config->readNumEntry("Enable Mouse Wheel", true);
     
+
     // Comments tab settings
     uint  commentsFontColor;
     uint  commentsBgColor;
@@ -265,6 +275,16 @@ void SlideShowConfig::readSettings()
     
     commentsLinesLength   = m_config->readNumEntry("Comments Lines Length", 72);
 
+    // Advanced tab
+    bool enableCache, kbDisableFadeInOut, kbDisableCrossFade;
+    
+    kbDisableFadeInOut = m_config->readBoolEntry("KB Disable FadeInOut", false);
+    kbDisableCrossFade = m_config->readBoolEntry("KB Disable Crossfade", false);
+    
+    enableCache = m_config->readBoolEntry("Enable Cache", false);
+    m_cacheSize  = m_config->readNumEntry("Cache Size", 5);
+    
+    
     // -- Apply Settings to widgets ------------------------------
 
     m_openglCheckBox->setChecked(opengl);
@@ -295,10 +315,15 @@ void SlideShowConfig::readSettings()
     m_commentsFontChooser->setFont(*savedFont);
     delete savedFont;
 
+    m_kbDisableFadeCheckBox->setChecked(kbDisableFadeInOut);
+    m_kbDisableCrossfadeCheckBox->setChecked(kbDisableCrossFade);
+    
+    m_cacheCheckBox->setChecked(enableCache);
+    
     slotOpenGLToggled();
+    slotCacheToggled();
 }
 
-
 void SlideShowConfig::saveSettings()
 {
     if (!m_config) return;
@@ -361,27 +386,45 @@ void SlideShowConfig::saveSettings()
         m_config->writeEntry("Effect Name", effect);
 
     }
-    else {
+    else 
+    {
+      QMap<QString,QString> effects;
+      QMap<QString,QString> effectNames;
+      QMap<QString,QString>::Iterator it;
+    
+      // Load slideshowgl effects
+      effectNames = SlideShowGL::effectNamesI18N();
+
+      for (it = effectNames.begin(); it != effectNames.end(); ++it)
+        effects.insert(it.key(),it.data());
+
+      // Load Ken Burns effect
+      effectNames = SlideShowKB::effectNamesI18N();
+      for (it = effectNames.begin(); it != effectNames.end(); ++it)
+        effects.insert(it.key(),it.data());
 
         QString effect;
-        QMap<QString,QString> effectNames = SlideShowGL::effectNamesI18N();
-        QMap<QString,QString>::Iterator it;
 
-        for (it = effectNames.begin(); it != effectNames.end(); ++it) {
-            if (it.data() == m_effectsComboBox->currentText()) {
+        for (it = effects.begin(); it != effects.end(); ++it) {
+            if ( it.data() == m_effectsComboBox->currentText()) {
                 effect = it.key();
                 break;
             }
         }
 
         m_config->writeEntry("Effect Name (OpenGL)", effect);
-
     }
 
+    // Advanced settings
+    m_config->writeEntry("KB Disable FadeInOut", m_kbDisableFadeCheckBox->isChecked());
+    m_config->writeEntry("KB Disable Crossfade", m_kbDisableCrossfadeCheckBox->isChecked());
+    
+    m_config->writeEntry("Enable Cache", m_cacheCheckBox->isChecked());
+    m_config->writeEntry("Cache Size", m_cacheSizeSpinBox->value());
+    
     m_config->sync();
 }
 
-
 void SlideShowConfig::addItems(const KURL::List& fileList)
 {
     if (fileList.isEmpty()) return;
@@ -400,9 +443,9 @@ void SlideShowConfig::addItems(const KURL::List& fileList)
 
         ImageItem *item = new ImageItem( m_ImagesFilesListBox,
                                          currentFile.path().section('/', -1 ),   // File name with extension.
-                                                 comments,                               // Image comments.
-                                                         currentFile.path().section('/', 0, -1), // Complete path with file name.
-                                                                 albumName                               // Album name.
+                                         comments,                               // Image comments.
+                                         currentFile.path().section('/', 0, -1), // Complete path with file name.
+                                         albumName                               // Album name.
                                        );
 
         item->setName( currentFile.path().section('/', -1) );
@@ -414,29 +457,21 @@ void SlideShowConfig::addItems(const KURL::List& fileList)
     m_ImagesFilesListBox->centerCurrentItem();
 }
 
-
-
-// ============================= SLOTS ===========================================
-
-
 void SlideShowConfig::slotCommentsBgColorChanged()
 {
     m_commentsFontChooser->setBackgroundColor(m_commentsBgColor->color());
 }
 
-
 void SlideShowConfig::slotCommentsFontColorChanged()
 {
     m_commentsFontChooser->setColor(m_commentsFontColor->color());
 }
 
-
 void SlideShowConfig::slotPrintCommentsToggled()
 {
     m_tabWidget->setTabEnabled(commentsTab, m_printCommentsCheckBox->isChecked());
 }
 
-
 void SlideShowConfig::slotUseMillisecondsToggled()
 {
 
@@ -464,6 +499,25 @@ void SlideShowConfig::slotUseMillisecondsToggled()
     }
 }
 
+void SlideShowConfig::slotEffectChanged()
+{
+  bool isKB = m_effectsComboBox->currentText() == i18n("Ken Burns");
+  
+  m_printNameCheckBox->setEnabled(!isKB);
+  m_printProgressCheckBox->setEnabled(!isKB);
+  m_printCommentsCheckBox->setEnabled(!isKB);
+  
+  m_cacheButtonGroup->setEnabled(!isKB);
+}
+
+void SlideShowConfig::slotCacheToggled()
+{
+  bool isEnabled = m_cacheCheckBox->isChecked();
+  
+  m_cacheSizeLabel1->setEnabled(isEnabled);
+  m_cacheSizeLabel2->setEnabled(isEnabled);
+  m_cacheSizeSpinBox->setEnabled(isEnabled);
+}
 
 void SlideShowConfig::slotOpenGLToggled()
 {
@@ -475,15 +529,15 @@ void SlideShowConfig::slotOpenGLToggled()
     }
     
     ShowNumberImages( m_ImagesFilesListBox->count() );
+    
+//    slotEffectChanged();
 }
 
-
 void SlideShowConfig::slotDelayChanged()
 {
     ShowNumberImages( m_ImagesFilesListBox->count() );
 }
 
-
 void SlideShowConfig::slotSelection()
 {
     KURL::List urlList;
@@ -532,7 +586,6 @@ void SlideShowConfig::slotSelection()
     }
 }
 
-
 void SlideShowConfig::slotImagesFilesSelected( QListBoxItem *item )
 {
     
@@ -565,13 +618,11 @@ void SlideShowConfig::slotImagesFilesSelected( QListBoxItem *item )
     m_label7->setText(i18n("Image no. %1").arg(index + 1));
 }
 
-
 void SlideShowConfig::slotAddDropItems(KURL::List filesUrl)
 {
     addItems(filesUrl);
 }
 
-
 void SlideShowConfig::slotImagesFilesButtonAdd( void )
 {
     KURL::List ImageFilesList =
@@ -580,7 +631,6 @@ void SlideShowConfig::slotImagesFilesButtonAdd( void )
         addItems( ImageFilesList );
 }
 
-
 void SlideShowConfig::slotImagesFilesButtonDelete( void )
 {
     for (uint i = 0 ; i < m_ImagesFilesListBox->count() ; ++i)
@@ -598,7 +648,6 @@ void SlideShowConfig::slotImagesFilesButtonDelete( void )
     ShowNumberImages( m_ImagesFilesListBox->count() );
 }
 
-
 void SlideShowConfig::slotImagesFilesButtonUp( void )
 {
     int Cpt = 0;
@@ -634,7 +683,6 @@ void SlideShowConfig::slotImagesFilesButtonUp( void )
     m_ImagesFilesListBox->setCurrentItem(Index-1);
 }
 
-
 void SlideShowConfig::slotImagesFilesButtonDown( void )
 {
     int Cpt = 0;
@@ -670,7 +718,6 @@ void SlideShowConfig::slotImagesFilesButtonDown( void )
     m_ImagesFilesListBox->setCurrentItem(Index+1);
 }
 
-
 void SlideShowConfig::ShowNumberImages( int Number )
 {
     QTime TotalDuration (0, 0, 0);
@@ -693,26 +740,22 @@ void SlideShowConfig::ShowNumberImages( int Number )
         m_label6->setText(i18n("%1 images [%2]").arg(Number).arg(TotalDuration.toString()));
 }
 
-
 void SlideShowConfig::slotGotPreview(const KFileItem*, const QPixmap &pixmap)
 {
     m_ImageLabel->setPixmap(pixmap);
     m_thumbJob = 0L;
 }
 
-
 void SlideShowConfig::slotFailedPreview(const KFileItem*)
 {
     m_thumbJob = 0L;
 }
 
-
 void SlideShowConfig::SlotPortfolioDurationChanged ( int )
 {
     ShowNumberImages( m_ImagesFilesListBox->count() );
 }
 
-
 void SlideShowConfig::slotStartClicked()
 {
     saveSettings();
@@ -739,6 +782,4 @@ void SlideShowConfig::slotHelp()
                                              "kipi-plugins");
 }
 
-
 }  // NameSpace KIPISlideShowPlugin
-
