@@ -4,7 +4,7 @@
  * Date  : 2004-11-30
  * Description :
  *
- * Copyright 2004-2005 by Renchi Raju
+ * Copyright 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -79,7 +79,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
     // About data and help button.
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Gallery Export"),
-                                           NULL,
+                                           0,
                                            KAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to export image collection to remote Gallery server."),
                                            "(c) 2003-2005, Renchi Raju");
@@ -93,7 +93,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, QWidget *parent, Galler
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Gallery Export Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     GalleryWidget* widget = new GalleryWidget(this);
